import _typeof from "@babel/runtime/helpers/typeof";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import chroma from "chroma-js";
export var insertIf = function insertIf() {
  var obj = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var condition = arguments.length > 1 ? arguments[1] : undefined;
  var isArray = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  if (condition) {
    return obj;
  }

  if (isArray) {
    return [];
  }

  return {};
}; // https://github.com/styled-components/styled-components/issues/630

export function withProps() {
  return function (fn) {
    return fn;
  };
} // Color utils

/**
 * Used for parsing hsl color values defined in [h, s, l] format
 * into a chroma object
 */

export var hslToChroma = function hslToChroma(hsl) {
  var _hsl = _slicedToArray(hsl, 3),
      h = _hsl[0],
      s = _hsl[1],
      l = _hsl[2];

  return chroma.hsl(h, s / 100, l / 100);
};
/**
 * Checks if the color is light or darks based on its L value in
 * the HSL color scale.
 * @param color A chroma color instance
 */

export var isLightColor = function isLightColor(color) {
  return color.get("hsl.l") >= 0.5;
};
/**
 * Returns font color of updated lightness on hover
 * @param color A chroma color instance
 */

export var getHoverFontColor = function getHoverFontColor(color) {
  return isLightColor(color) ? color.set("hsl.l", "-0.3") : color.set("hsl.l", "+0.3");
};
/**
 * Returns background color of updated lightness on hover
 * @param color A chroma color instance
 */

export var getHoverBackgroundColor = function getHoverBackgroundColor(color) {
  return isLightColor(color) ? color.set("hsl.l", "-0.1") : color.set("hsl.l", "+0.1");
};
/**
 * Determines the appropriate font color based on the background color.
 */

export var getFontColor = function getFontColor(theme, backGroundColor) {
  return isLightColor(backGroundColor) ? theme.chromaPalette.Neutral90 : theme.chromaPalette.Neutral0;
};

var createParsedColorTheme = function createParsedColorTheme(theme, backgroundColor) {
  return {
    background: backgroundColor,
    font: getFontColor(theme, backgroundColor)
  };
};
/**
 * Creates an object with background and font properties initialized
 * with appropriate chroma colors.
 * @param backGroundColor A plain CSS color string
 */


export var parseCustomColor = function parseCustomColor(theme, customColor) {
  if (!(chroma.valid(customColor) || _typeof(customColor) === "object" && chroma.valid(customColor.color) && chroma.valid(customColor.secondaryColor))) {
    throw new Error("Provided color theme contains invalid color values");
  }

  if (_typeof(customColor) === "object") {
    return {
      font: chroma(customColor.secondaryColor),
      background: chroma(customColor.color)
    };
  }

  customColor = chroma(customColor);
  return createParsedColorTheme(theme, customColor);
};
/**
 * Creates an object with background and font properties initialized
 * with appropriate chroma colors.
 * @param backGroundColor One of the predefined preset values
 */

export var parseColorPreset = function parseColorPreset(theme, backgroundColor) {
  backgroundColor = theme.secondaryPalette[backgroundColor];
  return createParsedColorTheme(theme, backgroundColor);
};
/**
 * Get color from Styled Component Props
 */

export var getThemeColor = function getThemeColor(props, color) {
  var chromaPalette = props.theme.knitui.chromaPalette;
  return chromaPalette[color].hex();
};
/**
 * Get different lightness of passed color, range of lightness is between 0 to 100
 */

export var getColorOfLightness = function getColorOfLightness(props, color, lightness) {
  var chromaPalette = props.theme.knitui.chromaPalette;
  var computedColor;
  if (chromaPalette.hasOwnProperty(color)) computedColor = chromaPalette[color].set("hsl.l", lightness / 100).hex();else if (chroma.valid(color)) computedColor = chroma(color).set("hsl.l", lightness / 100).hex();else computedColor = color;
  return computedColor;
};
/**
 * Get font-size from Styled Component Props
 */

export var getThemeFontSize = function getThemeFontSize(props, size) {
  var knitui = props.theme.knitui;
  return knitui.typography[size].fontSize;
};
/**
 * Get line-height from Styled Component Props
 */

export var getThemeLineHeight = function getThemeLineHeight(props, size) {
  var knitui = props.theme.knitui;
  return knitui.typography[size].lineHeight;
};
/**
 * Get OS of current platform
 */

export var getOSName = function getOSName() {
  var platform = window.navigator.platform;
  var userAgent = window.navigator.userAgent;
  var macOSList = ["Macintosh", "MacIntel", "MacPPC", "Mac68K"];
  var windowOSList = ["Windows", "Win16", "Win32", "WinCE"];
  var iOSList = ["iPhone", "iPad", "iPod"];
  var os;

  if (macOSList.includes(platform)) {
    os = "MacOS";
  } else if (windowOSList.includes(platform)) {
    os = "Windows";
  } else if (iOSList.includes(platform)) {
    os = "iOS";
  } else if (/Android/.test(userAgent)) {
    os = "Android";
  } else if (/Linux/.test(userAgent)) {
    os = "Linux";
  }

  return os;
};