import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import chroma from "chroma-js";
import { hslToChroma } from "../_utils"; // Helpers

var multiply = function multiply(a, b) {
  return a * b;
};

var baseUnit = 10;
/**
 * The generateTheme function is exposed to user so that palette can have
 * additional color, also palette is exposed to user so he can get
 * existing colors
 */

var generateTheme = function generateTheme(palette) {
  /**
   * Create a new palette by parsing the corresponding color values
   * into chroma objects.
   */
  var chromaPalette = Object.entries(palette).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        colorName = _ref2[0],
        values = _ref2[1];

    return _defineProperty({}, colorName, hslToChroma(values.hsl));
  }).reduce(function (acc, cur) {
    return _objectSpread({}, acc, cur);
  }, {});
  /** Default Theme --> */

  /**
   * The defualt theme object is created every time so that theme is not
   * get overlaped, as Modules do immutable export
   */

  var defaultTheme = {
    baseUnit: 10,
    base: "".concat(baseUnit, "px"),
    baseIncrementUnit: 0.2,
    // Unit measurements (measurements relative to base unit i.e 10px)
    unit12: 1.2,
    unit14: 1.4,
    unit16: 1.6,
    unit18: 1.8,
    // Font size and line height associations
    typography: {
      10: {
        fontSize: 1.0,
        lineHeight: 1.6
      },
      12: {
        fontSize: 1.2,
        lineHeight: 1.8
      },
      14: {
        fontSize: 1.4,
        lineHeight: 2.0
      },
      16: {
        fontSize: 1.6,
        lineHeight: 2.0
      },
      18: {
        fontSize: 1.8,
        lineHeight: 2.4
      },
      20: {
        fontSize: 2.0,
        lineHeight: 2.8
      }
    },
    // Type
    fontFamily: "InterRegular, -apple-system, BlinkMacSystemFont, Segoe UI, Roboto, Helvetica, Arial, sans-serif, Apple Color Emoji, Segoe UI Emoji, Segoe UI Symbol",
    fontSize12: "1.2rem",
    fontSize14: "1.4rem",
    // for Paragraphs
    fontSize16: "1.6rem",
    // for Leads
    fontSize18: "1.8rem",
    // for Headings
    fontSize20: "2rem",
    primaryHues: {
      default: "#293979"
    },
    // TODO: This mapping should be defined by UX
    secondaryPalette: {
      neutral: chromaPalette.Blue100,
      danger: chromaPalette.Crimson80,
      success: chromaPalette.Green80,
      warning: chromaPalette.Yellow80,
      unsaved: chromaPalette.Magenta80,
      regular: chromaPalette.Neutral10
    },
    // TODO: Remove this and its references and use chromaPalette directly
    shades: {
      // Shades of gray
      white: chromaPalette.Neutral0,
      gray95: chromaPalette.Neutral10,
      gray90: chromaPalette.Neutral20,
      gray85: chromaPalette.Neutral30,
      gray50: chromaPalette.Neutral50,
      gray20: chromaPalette.Neutral80,
      black: chromaPalette.Neutral90,
      transparent: chroma.hsl(0, 0, 0, 0),
      // Shades of blue
      lightBlue: chromaPalette.Azure80,
      blue40: chroma.hsl(205, 0.85, 0.4),
      blue50: chroma.hsl(216, 1, 0.5)
    },
    // Properties
    lineHeight: "2rem",
    borderRadius: "".concat(multiply(0.4, baseUnit), "px"),
    defaultPadding: "".concat(multiply(0.4, baseUnit), "px ").concat(baseUnit, "px"),
    defaultTextPadding: "1.4rem",
    defaultBorderWidth: "0.1",
    // input
    inputFocusOutline: "none",
    inputBorderRadius: "4px",
    inputBorderColor: "transparent",
    inputFocusBoxShadow: "0 0 2px #0066ff",
    inputBgDefault: chromaPalette.Neutral10,
    inputColor: chromaPalette.Neutral90,
    inputPlaceholderColor: chromaPalette.Neutral45,
    inputPlaceholderColorActive: chromaPalette.Neutral40,
    inputBgHover: chromaPalette.Neutral20,
    inputBgActive: chromaPalette.Neutral0,
    inputBgFocus: chromaPalette.Neutral0,
    inputBgDisabled: chromaPalette.Neutral50,
    inputFocusBorderColor: chromaPalette.Azure80,
    inputHoverBorderColor: chromaPalette.Neutral40,
    inputSuccessBorder: chromaPalette.Green80,
    inputWarningBorder: chromaPalette.Yellow80,
    inputErrorBorder: chromaPalette.Crimson80,
    inputSelectionBg: chromaPalette.Sapphire10,
    inputLabelColor: chromaPalette.Neutral50,
    inputNotificationColor: chromaPalette.Neutral45,
    // switch
    switchWrapperHeight: "1.6rem",
    switchWrapperHeightSm: "1.1rem",
    switchWrapperWidth: "2.8rem",
    switchWrapperWidthSm: "2.1rem",
    wrapperBorderColor: "hsl(0, 0%, 90%)",
    wrapperBgColor: "hsl(0, 0%, 90%)",
    switchTrackerHeight: "1rem",
    switchTrackerHeightSm: "0.7rem",
    switchTrackerWidth: "1rem",
    switchTrackerWidthSm: "0.7rem",
    switchCheckedBorderColor: "hsl(118, 100%, 21%)",
    switchCheckedBgColor: "hsl(118, 100%, 21%)",
    switchCheckedDisabledBorderColor: "hsl(0, 0%, 90%)",
    switchCheckedDisabledBgColor: "hsl(0, 0%, 90%)",
    switchFocusColor: "hsl(216, 100%, 20%)",
    // radio
    smallRadioSize: "1.2rem",
    mediumRadioSize: "1.4rem",
    smallRadioBead: "0.6rem",
    mediumRadioBead: "0.8rem",
    radioDisabledColor: chromaPalette.Neutral10,
    // Modal
    modalBorder: "1px solid ".concat(chromaPalette.Neutral30),
    modalBorderRadius: "0.4rem",
    modalMaxContentHeightOffset: 14,
    modalPadding: {
      vertical: 2.1,
      horizontal: 2.8
    },
    modalHeaderPadding: {
      vertical: 1.4,
      horizontal: 2.8
    },
    modalTitleTypographySize: 20,
    modalMinHeight: 35
    /**
     * Passing general theme object with knitui property so it can
     * merge with other nested ThemeProvider,
     * https://github.com/styled-components/styled-components/issues/244#issuecomment-262577541
     * it will emphasise ignorance of knitui-theme as property of
     * whole theme object of styled-component
     */

  };
  return {
    knitui: _objectSpread({}, defaultTheme, {
      chromaPalette: chromaPalette
    })
  };
};

export default generateTheme;