import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _extends from "@babel/runtime/helpers/extends";
import React, { useState, useEffect } from "react";
import { AlertContainer, AlertContent, StyledAlertIcon, AlertHeading, AlertContentWrapper, StyledAlertPicture, StyledAlertAction, AlertActionsWrapper, CloseIcon } from "./StyledAlert";
var defaultIcons = {
  neutral: "oInfo",
  unsaved: "oInfo",
  danger: "oError",
  warning: "oWarning",
  success: "oCheckCircle"
};

var getClassName = function getClassName(prfxCls, suffix) {
  return prfxCls ? prfxCls + suffix : "";
};

var renderIcon = function renderIcon(scProps) {
  var _scProps$customProps = scProps.customProps,
      prefixClassName = _scProps$customProps.prefixClassName,
      image = _scProps$customProps.image,
      icon = _scProps$customProps.icon,
      type = _scProps$customProps.type;
  scProps.className = getClassName(prefixClassName, "-knit-alert-icon");
  if (image) return React.createElement(StyledAlertPicture, _extends({}, scProps, {
    src: image
  }));
  if (icon) return React.createElement(StyledAlertIcon, _extends({}, scProps, {
    type: icon
  }));
  return React.createElement(StyledAlertIcon, _extends({}, scProps, {
    type: defaultIcons[type]
  }));
};

var renderActions = function renderActions(scProps) {
  var _scProps$customProps2 = scProps.customProps,
      actions = _scProps$customProps2.actions,
      prfxCls = _scProps$customProps2.prefixClassName,
      type = _scProps$customProps2.type,
      alertKey = _scProps$customProps2.alertKey;

  if (Array.isArray(actions) && actions.length == 0) {
    return null;
  } // Only pick top 2 actions in case more are supplied


  actions = actions.slice(0, 2);
  return React.createElement(AlertActionsWrapper, _extends({
    className: getClassName(prfxCls, "-knit-alert-action-wrapper")
  }, scProps), actions.map(function (action, index) {
    return React.createElement(StyledAlertAction, _extends({
      className: getClassName(prfxCls, "-knit-alert-action"),
      key: index,
      type: "secondary",
      label: action.text,
      onClick: function onClick() {
        return action.callback(alertKey);
      },
      alertType: type
    }, scProps));
  }));
};

var Alert = function Alert(props) {
  var className = props.className,
      rest = _objectWithoutProperties(props, ["className"]); // To clear autoDismiss setTimeoutInterval during unmount


  var interval;
  var scProps = {
    className: className,
    customProps: rest
  };
  var image = rest.image,
      prefixClassName = rest.prefixClassName,
      heading = rest.heading,
      multiLine = rest.multiLine,
      autoDismiss = rest.autoDismiss,
      dismissDuration = rest.dismissDuration,
      actions = rest.actions,
      onClose = rest.onClose,
      onExit = rest.onExit,
      alertKey = rest.alertKey;

  var _useState = useState(true),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1]; // To get className


  var propsWithClass = function propsWithClass(suffix, className) {
    scProps.className = (prefixClassName ? "".concat(prefixClassName).concat(suffix, " ") : "") + (className ? "".concat(className, " ") : "");
    return scProps;
  };

  var isIcon = props.hasOwnProperty("icon");
  var isAction = actions && actions.length > 0; // Execute once, when Component will be mounted

  useEffect(function () {
    // Show error when more than two actions are passed
    if (actions && actions.length > 2) {
      console.warn("Only two actions can be add to Alert, others will be ignored");
    } // heading only exist if multiline prop is true


    if (heading && !multiLine) {
      console.error("Please pass multiLine prop to use headings");
    } // When unmount onExit function will be called


    return function () {
      interval && clearInterval(interval);
      onExit && onExit(alertKey);
    };
  }, []); // To Auto dismiss the alert after some duration, can use transition delay check out again

  if (autoDismiss) interval = setTimeout(function () {
    return fadeAway();
  }, dismissDuration); // called by both AutoDismiss and Close Icon click

  var fadeAway = function fadeAway(event) {
    if (onClose) {
      onClose(alertKey);
    }

    setOpen(false);
  };

  return React.createElement(AlertContainer, _extends({
    "data-testid": "alert-container"
  }, propsWithClass("-knit-alert", "".concat(scProps.className ? scProps.className : "").concat(open ? "" : " hide"))), (isIcon || image) && renderIcon(scProps), React.createElement(AlertContentWrapper, propsWithClass("-knit-alert-content-wrapper"), heading && multiLine && React.createElement(AlertHeading, propsWithClass("-knit-alert-heading"), heading), React.createElement(AlertContent, propsWithClass("-knit-alert-content"), props.content), isAction && renderActions(scProps)), !autoDismiss && React.createElement(CloseIcon, _extends({
    "data-testid": "alert-close",
    icon: "oClose",
    onClick: function onClick(e) {
      return fadeAway(e);
    }
  }, propsWithClass("-knit-alert-close"))));
};

Alert.defaultProps = {
  type: "neutral",
  size: "small",
  placement: "bottomLeft",
  multiLine: false,
  actions: []
};
export default Alert;