import styled from "styled-components";
import { Icon, Button } from "..";
import { parseColorPreset, parseCustomColor } from "../../common/_utils";
var width = {
  "x-small": 28,
  small: 35,
  medium: 49,
  large: 77
};

var getWidth = function getWidth(props) {
  var size = props.customProps.size;
  return width[size];
};

var getFontSize = function getFontSize(props) {
  var typography = props.theme.knitui.typography;
  return typography[14].fontSize;
};

var getLineHeight = function getLineHeight(props) {
  var typography = props.theme.knitui.typography;
  return typography[14].lineHeight;
};

var getHeadingFontSize = function getHeadingFontSize(props) {
  var typography = props.theme.knitui.typography;
  return typography[18].fontSize;
};

var getHeadingLineHeight = function getHeadingLineHeight(props) {
  var typography = props.theme.knitui.typography;
  return typography[18].lineHeight;
};

var parseColorTheme = function parseColorTheme(props) {
  var _props$customProps = props.customProps,
      customColor = _props$customProps.customColor,
      type = _props$customProps.type,
      theme = props.theme.knitui;
  return customColor ? parseCustomColor(theme, customColor) : parseColorPreset(theme, type);
};

var getBackgroundColor = function getBackgroundColor(props) {
  return parseColorTheme(props).background.hex();
};

var getBorderRadius = function getBorderRadius(props) {
  var borderRadius = props.theme.knitui.borderRadius;
  return borderRadius;
};

var getFontColor = function getFontColor(props) {
  return parseColorTheme(props).font;
};

var getContentWrapperDirection = function getContentWrapperDirection(props) {
  var _props$customProps2 = props.customProps,
      multiLine = _props$customProps2.multiLine,
      heading = _props$customProps2.heading,
      actions = _props$customProps2.actions;
  var isAction = actions && actions.length > 0;
  return (heading || isAction) && multiLine ? "column" : "row";
};

var getIconVerticalAlign = function getIconVerticalAlign(props) {
  var _props$customProps3 = props.customProps,
      multiLine = _props$customProps3.multiLine,
      actions = _props$customProps3.actions,
      heading = _props$customProps3.heading;
  var isAction = actions && actions.length > 0;
  return multiLine && !(heading || isAction) || !multiLine ? "center" : "";
};

var getIconMargin = function getIconMargin(props) {
  var _props$customProps4 = props.customProps,
      multiLine = _props$customProps4.multiLine,
      heading = _props$customProps4.heading;
  return multiLine && heading ? "0.2rem 1.4rem 0.2rem 0" : "0 1.4rem 0 0";
};

var getCloseIconMargin = function getCloseIconMargin(props) {
  var multiLine = props.customProps.multiLine;
  return "".concat(multiLine ? "-0.4rem -0.4rem" : "0 0", " 0 1.4rem");
};

var getActionWrapperMargin = function getActionWrapperMargin(props) {
  var multiLine = props.customProps.multiLine;
  return "".concat(multiLine ? "1.4rem" : "0", " 0 0 0}");
};

export var AlertContainer =
/*#__PURE__*/
styled("div").withConfig({
  displayName: "StyledAlert__AlertContainer",
  componentId: "t41nzf-0"
})(["display:flex;box-sizing:border-box;overflow:hidden;width:", "rem;border-radius:", ";padding:1.4rem;color:", ";background:", ";opacity:1;transition:all 0.25s;&.hide{opacity:0;}"], function (props) {
  return getWidth(props);
}, function (props) {
  return getBorderRadius(props);
}, function (props) {
  return getFontColor(props);
}, function (props) {
  return getBackgroundColor(props);
});
export var AlertContentWrapper =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "StyledAlert__AlertContentWrapper",
  componentId: "t41nzf-1"
})(["display:flex;width:100%;flex-direction:", ";justify-content:space-between;", ";"], function (props) {
  return getContentWrapperDirection(props);
}, function (_ref) {
  var multiLine = _ref.customProps.multiLine;
  return !multiLine ? "align-items: center;" : "";
});
export var AlertContent =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "StyledAlert__AlertContent",
  componentId: "t41nzf-2"
})(["font-size:", ";line-height:", ";color:", ";"], function (props) {
  return "".concat(getFontSize(props), "rem");
}, function (props) {
  return "".concat(getLineHeight(props), "rem");
}, function (props) {
  return "".concat(getFontColor(props));
});
export var StyledAlertIcon =
/*#__PURE__*/
styled(Icon).attrs(function (props) {
  return {
    fill: getFontColor(props),
    width: "2rem",
    height: "2rem"
  };
}).withConfig({
  displayName: "StyledAlert__StyledAlertIcon",
  componentId: "t41nzf-3"
})(["align-self:", ";margin:", ";"], function (props) {
  return getIconVerticalAlign(props);
}, function (props) {
  return getIconMargin(props);
});
export var CloseIcon =
/*#__PURE__*/
styled(Button).attrs(function (props) {
  return {
    customColor: getBackgroundColor(props),
    style: {
      padding: "0rem"
    }
  };
}).withConfig({
  displayName: "StyledAlert__CloseIcon",
  componentId: "t41nzf-4"
})(["flex-basis:0;margin:", ";align-self:", ";"], function (props) {
  return getCloseIconMargin(props);
}, function (_ref2) {
  var multiLine = _ref2.customProps.multiLine;
  return !multiLine ? "center" : "flex-start";
});
export var AlertHeading =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "StyledAlert__AlertHeading",
  componentId: "t41nzf-5"
})(["font-size:", ";line-height:", ";margin-bottom:0.7rem;"], function (props) {
  return "".concat(getHeadingFontSize(props), "rem");
}, function (props) {
  return "".concat(getHeadingLineHeight(props), "rem");
});
export var StyledAlertPicture =
/*#__PURE__*/
styled.img.withConfig({
  displayName: "StyledAlert__StyledAlertPicture",
  componentId: "t41nzf-6"
})(["min-width:2rem;height:2rem;border-radius:1.2rem;align-self:", ";margin:", ";"], function (props) {
  return getIconVerticalAlign(props);
}, function (props) {
  return getIconMargin(props);
});
export var StyledAlertAction =
/*#__PURE__*/
styled(Button).attrs(function (props) {
  return {
    customColor: getBackgroundColor(props)
  };
}).withConfig({
  displayName: "StyledAlert__StyledAlertAction",
  componentId: "t41nzf-7"
})(["flex-shrink:0;text-transform:uppercase;font-size:", ";line-height:", ";cursor:pointer;"], function (props) {
  return "".concat(getFontSize(props), "rem");
}, function (props) {
  return "".concat(getLineHeight(props), "rem");
});
export var AlertActionsWrapper =
/*#__PURE__*/
styled.span.withConfig({
  displayName: "StyledAlert__AlertActionsWrapper",
  componentId: "t41nzf-8"
})(["margin:", ";display:flex;", ":not(:last-child){margin-right:0.7rem;}"], function (props) {
  return getActionWrapperMargin(props);
}, StyledAlertAction);