import _extends from "@babel/runtime/helpers/extends";
import React from "react";
import AlertContext from "./AlertContext";
import hoistNonReactStatics from "hoist-non-react-statics";

function withAlerts(Component) {
  // Reference for ForwardRef - https://reactjs.org/docs/higher-order-components.html#refs-arent-passed-through
  var WrappedComponent = React.forwardRef(function (props, ref) {
    return React.createElement(AlertContext.Consumer, null, function (context) {
      return React.createElement(Component, _extends({}, props, {
        ref: ref,
        addAlert: context.addAlert,
        removeAlert: context.removeAlert
      }));
    });
  }); // To display name during debuging

  if (process.env.NODE_ENV !== "production") {
    WrappedComponent.displayName = "WithAlert(".concat(getDisplayName(Component), ")");
  }

  function getDisplayName(Component) {
    return Component.displayName || Component.name || "Component";
  } // Reference https://reactjs.org/docs/higher-order-components.html#static-methods-must-be-copied-over


  hoistNonReactStatics(WrappedComponent, Component);
  return WrappedComponent;
}

export default withAlerts;