import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from "react";
import styled from "styled-components";
import { getThemeColor } from "../../common/_utils";
import { oAccountCircle as UserProfileIcon } from "../Icon/Icons";

var getBoxShadowStyle = function getBoxShadowStyle(props) {
  var shades = props.theme.knitui.shades,
      disabled = props.customProps.disabled;
  return disabled ? "none" : "0px 0px 2px ".concat(shades.blue50.hex());
};

var getFontSize = function getFontSize(props) {
  var size = props.customProps.size;
  return "calc(1.4 * ".concat(size, " / 2.4)");
};

var getLineHeight = function getLineHeight(props) {
  var size = props.customProps.size;
  return "calc(2.0 * ".concat(size, " / 2.4)");
};

var getBackgroundColor = function getBackgroundColor(props, state) {
  var _props$customProps = props.customProps,
      isPicture = _props$customProps.isPicture,
      isName = _props$customProps.isName,
      isIcon = _props$customProps.isIcon,
      disabled = _props$customProps.disabled;

  if (isPicture || isIcon) {
    return "transparent";
  } else if (isName) {
    if (disabled || state === "default") {
      return getThemeColor(props, "Neutral10");
    } else if (state === "hover" || state === "focus") {
      return getThemeColor(props, "Neutral20");
    } else {
      return getThemeColor(props, "Neutral10");
    }
  }
};

var getBorderStyle = function getBorderStyle(props, state) {
  var _props$customProps2 = props.customProps,
      isPicture = _props$customProps2.isPicture,
      isName = _props$customProps2.isName,
      disabled = _props$customProps2.disabled;
  var focusColor = getThemeColor(props, "Azure80");
  var hoverColor = getThemeColor(props, "Neutral20");
  var defaultColor = getThemeColor(props, "Neutral10");

  if (state === "focus" && !disabled) {
    return "1px solid ".concat(focusColor);
  }

  if (isPicture || isName) {
    if (state === "default" || disabled) {
      return "1px solid ".concat(defaultColor);
    } else if (state === "hover") {
      return "1px solid ".concat(hoverColor);
    }
  }
  /* if(isIcon) with (state === "default" || state === "hover" || disabled), focus is already taken care of,
   * so directly returning transparent style in all other case of isIcon
   * because of the ts-lint error `not all paths return` to make this condition default
   */


  return "1px solid transparent";
};

var getMarginStyle = function getMarginStyle(props) {
  var _props$customProps3 = props.customProps,
      isPicture = _props$customProps3.isPicture,
      isIcon = _props$customProps3.isIcon;
  return isIcon || isPicture ? "-1px" : "0";
};

var getFillColor = function getFillColor(props, state) {
  var _props$customProps4 = props.customProps,
      isPicture = _props$customProps4.isPicture,
      isName = _props$customProps4.isName,
      isIcon = _props$customProps4.isIcon,
      disabled = _props$customProps4.disabled;

  if (isPicture || isName) {
    return "transparent";
  } else if (isIcon) {
    if (state === "default" || disabled) {
      return getThemeColor(props, "Neutral10");
    } else if (state === "hover" || state === "focus") {
      return getThemeColor(props, "Neutral20");
    }
  }
};

var getOpacity = function getOpacity(props) {
  var isIcon = props.customProps.isIcon;
  return isIcon ? 1 : 0.4;
};

var AvatarBase =
/*#__PURE__*/
styled.button.withConfig({
  displayName: "Avatar__AvatarBase",
  componentId: "ldig7w-0"
})(["width:", ";height:", ";overflow:hidden;border-radius:50%;outline:none;cursor:pointer;color:", ";font-size:", ";line-height:", ";mask-image:radial-gradient(white,black);background:", ";border:", ";img{width:", ";height:", ";margin:", ";user-drag:none;user-select:none;transition:transform 120ms;}svg{margin:", ";path{fill:", ";}}:hover{img{transform:scale(1.05);}background:", ";border:", ";svg path{fill:", ";}}:focus,:active{background:", ";border:", ";svg path{fill:", ";}box-shadow:", ";}:disabled{img{transform:none;}opacity:", ";cursor:not-allowed;}"], function (_ref) {
  var customProps = _ref.customProps;
  return customProps.size;
}, function (_ref2) {
  var customProps = _ref2.customProps;
  return customProps.size;
}, function (props) {
  return getThemeColor(props, "Neutral90");
}, function (props) {
  return getFontSize(props);
}, function (props) {
  return getLineHeight(props);
}, function (props) {
  return getBackgroundColor(props, "default");
}, function (props) {
  return getBorderStyle(props, "default");
}, function (_ref3) {
  var customProps = _ref3.customProps;
  return customProps.size;
}, function (_ref4) {
  var customProps = _ref4.customProps;
  return customProps.size;
}, function (props) {
  return getMarginStyle(props);
}, function (props) {
  return getMarginStyle(props);
}, function (props) {
  return getFillColor(props, "default");
}, function (props) {
  return getBackgroundColor(props, "hover");
}, function (props) {
  return getBorderStyle(props, "hover");
}, function (props) {
  return getFillColor(props, "hover");
}, function (props) {
  return getBackgroundColor(props, "focus");
}, function (props) {
  return getBorderStyle(props, "focus");
}, function (props) {
  return getFillColor(props, "focus");
}, function (props) {
  return getBoxShadowStyle(props);
}, function (props) {
  return getOpacity(props);
});

var Avatar = function Avatar(props) {
  var picture = props.picture,
      _props$size = props.size,
      size = _props$size === void 0 ? "24px" : _props$size,
      name = props.name,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      rest = _objectWithoutProperties(props, ["picture", "size", "name", "disabled"]);

  var isPicture = !!picture;
  var isName = !!name;
  var isIcon = !(isPicture || isName);
  var avatarTitle = isName ? name : isPicture ? "" : "Unknown User";
  var customProps = {
    isPicture: isPicture,
    isName: isName,
    isIcon: isIcon,
    size: size,
    disabled: disabled
  };
  return React.createElement(AvatarBase, _extends({
    "data-testid": "avatar",
    customProps: customProps,
    disabled: disabled,
    title: avatarTitle
  }, rest), isPicture && React.createElement("img", {
    src: picture
  }) || isName && name.toUpperCase()[0] || isIcon && React.createElement(UserProfileIcon, {
    width: size,
    height: size
  }));
};

export default Avatar;