import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { cloneElement, useState } from "react";
import styled from "styled-components";
import BreadcrumbItem, { StyledText } from "./BreadcrumbItem";
var StyledParent =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "Breadcrumb__StyledParent",
  componentId: "sc-1a81q2h-0"
})(["display:flex;max-width:", ";flex-wrap:wrap;width:fit-content;align-items:center;"], function (props) {
  return props.maxWidth || "initial";
});

var Breadcrumb = function Breadcrumb(props) {
  var className = props.className,
      rootStyle = props.rootStyle,
      maxWidth = props.maxWidth,
      children = props.children,
      _props$truncateTo = props.truncateTo,
      truncateTo = _props$truncateTo === void 0 ? Infinity : _props$truncateTo,
      separator = props.separator,
      activeStyles = props.activeStyles,
      childStyle = props.childStyle;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      showAll = _useState2[0],
      setShowAll = _useState2[1];

  var renderBreadcrumbs = function renderBreadcrumbs() {
    var updatedChildren = React.Children.count(children) > 1 ? preprocessCrumbs(children, separator, truncateTo, setShowAll, showAll, childStyle) : children;
    var crumbs = React.Children.map(updatedChildren, function (element, index) {
      if (!element) {
        return element;
      }

      return cloneElement(element, {
        key: index,
        childStyle: childStyle,
        activeStyles: activeStyles
      });
    });
    return crumbs;
  };

  return React.createElement(StyledParent, {
    className: className || "",
    maxWidth: maxWidth,
    style: rootStyle
  }, renderBreadcrumbs());
}; // Logic to insert separators among the list of children


var preprocessCrumbs = function preprocessCrumbs(crumbs, separator, truncateTo, setShowAll, showAll, childStyle) {
  // Container where we insert nodes and separators in appropriate places
  var updatedCrumbs = []; // A bool to check whether the ... is inserted or not

  var truncated = false; // Handle the range of truncateTo

  if (truncateTo < 1) {
    truncateTo = 1;
    console.warn("Prop 'truncateTo' has been set to 1 since it's the lowest possible value");
  }

  crumbs.forEach(function (crumb, index) {
    var shouldInsertCrumbs = index === 0 || index >= crumbs.length - truncateTo || showAll;

    if (shouldInsertCrumbs) {
      if (index !== crumbs.length - 1) {
        updatedCrumbs.push(cloneElement(crumb, {
          childStyle: childStyle
        }));
      } else {
        updatedCrumbs.push(cloneElement(crumb, {
          activeElement: true,
          childStyle: childStyle
        }));
      } // Insert nodes till last element


      if (index < crumbs.length - 1) {
        updatedCrumbs.push(React.createElement(StyledText, {
          style: childStyle,
          separator: true
        }, separator));
      }
    } else if (!truncated) {
      updatedCrumbs.push(React.createElement(StyledText, {
        style: childStyle,
        onClick: function onClick() {
          return setShowAll(true);
        }
      }, "..."));
      updatedCrumbs.push(React.createElement(StyledText, {
        style: childStyle,
        separator: true
      }, separator));
      truncated = true;
    }
  });
  return updatedCrumbs;
};

Breadcrumb.defaultProps = {
  separator: "/",
  truncateTo: Infinity
};
Breadcrumb.Item = BreadcrumbItem;
export default Breadcrumb;