import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useContext } from "react";
import Icon from "../Icon";
import { ButtonBase, ButtonInset, ButtonContent } from "./components";
import { ThemeContext } from "styled-components";
import { parseCustomColor, parseColorPreset } from "../../common/_utils";
var DEFAULT_COLOR_THEME = "neutral";
var insetPositions = {
  LEFT: "left",
  RIGHT: "right"
};

var ButtonWrapper = function ButtonWrapper(_ref) {
  var label = _ref.label,
      _ref$ghost = _ref.ghost,
      ghost = _ref$ghost === void 0 ? false : _ref$ghost,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? "medium" : _ref$size,
      href = _ref.href,
      _onClick = _ref.onClick,
      icon = _ref.icon,
      _ref$bare = _ref.bare,
      bare = _ref$bare === void 0 ? false : _ref$bare,
      insetLabel = _ref.insetLabel,
      _ref$insetPosition = _ref.insetPosition,
      insetPosition = _ref$insetPosition === void 0 ? "right" : _ref$insetPosition,
      _ref$colorPreset = _ref.colorPreset,
      colorPreset = _ref$colorPreset === void 0 ? DEFAULT_COLOR_THEME : _ref$colorPreset,
      customColor = _ref.customColor,
      insetCustomColor = _ref.insetCustomColor,
      customProps = _ref.customProps,
      rest = _objectWithoutProperties(_ref, ["label", "ghost", "size", "href", "onClick", "icon", "bare", "insetLabel", "insetPosition", "colorPreset", "customColor", "insetCustomColor", "customProps"]);

  var themeContext = useContext(ThemeContext);
  var knitui = themeContext.knitui; // Typography

  var typographySize = size === "small" ? knitui.typography[12] : knitui.typography[14];
  var iconSize = size === "small" ? "1.4rem" : "1.8rem";
  var baseFontSize = typographySize.fontSize;
  var baseLineHeight = typographySize.lineHeight;
  var insetFontSize = baseFontSize - knitui.baseIncrementUnit;
  var lowerTypographyUnit = knitui.typography["".concat(insetFontSize * 10)];
  var insetLineHeight = lowerTypographyUnit && lowerTypographyUnit.lineHeight || baseLineHeight; // Colors
  // Cannot be set as default arg since theme is not available in that context

  var DEFAULT_INSET_THEME = {
    background: knitui.chromaPalette.Neutral0,
    font: knitui.chromaPalette.Neutral80
  };
  var insetColorTheme = insetCustomColor ? parseCustomColor(knitui, insetCustomColor) : DEFAULT_INSET_THEME;
  var parsedColorTheme = customColor ? parseCustomColor(knitui, customColor) : parseColorPreset(knitui, colorPreset);
  return React.createElement(ButtonBase, _extends({
    customProps: {
      label: label,
      icon: icon,
      ghost: ghost,
      size: size,
      bare: bare,
      colorTheme: parsedColorTheme,
      fontSize: baseFontSize,
      lineHeight: baseLineHeight
    },
    onClick: function onClick(e) {
      return _onClick && _onClick(e) || href && window.location.assign(href);
    }
  }, rest), insetLabel && insetPosition === insetPositions.LEFT && React.createElement(ButtonInset, {
    customProps: {
      insetPosition: insetPosition,
      size: size,
      backgroundColor: insetColorTheme.background,
      fontColor: insetColorTheme.font,
      fontSize: "".concat(insetFontSize, "rem"),
      lineHeight: "".concat(insetLineHeight, "rem")
    }
  }, React.createElement("span", null, insetLabel)), React.createElement(ButtonContent, {
    customProps: {
      label: label,
      icon: icon,
      ghost: ghost,
      size: size,
      bare: bare,
      colorTheme: parsedColorTheme,
      fontSize: baseFontSize,
      lineHeight: baseLineHeight
    }
  }, icon ? React.createElement(Icon, {
    type: icon,
    size: iconSize
  }) : null, label), insetLabel && insetPosition === insetPositions.RIGHT && React.createElement(ButtonInset, {
    customProps: {
      insetPosition: insetPosition,
      size: size,
      backgroundColor: insetColorTheme.background,
      fontColor: insetColorTheme.font,
      fontSize: "".concat(insetFontSize, "rem"),
      lineHeight: "".concat(insetLineHeight, "rem")
    }
  }, React.createElement("span", null, insetLabel)));
};

import ButtonGroup from "./ButtonGroup";
ButtonWrapper.Group = ButtonGroup;
export default ButtonWrapper;