import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useEffect, useRef } from "react";
import { useCombobox } from "downshift";
import { Neutral10 } from "../../common/styles/palette";
var menuStyles = {
  backgroundColor: "white",
  fontWeight: "normal",
  position: "absolute"
};
var textContentStyle = {
  position: "absolute",
  top: 0,
  left: 0,
  visibility: "hidden",
  height: 0,
  overflow: "scroll",
  whiteSpace: "pre"
};

var DropdownCombobox = function DropdownCombobox(props) {
  var inputRef = props.inputRef,
      inputPlaceholder = props.inputPlaceholder,
      onKeyDown = props.onKeyDown,
      handleValueChange = props.handleValueChange,
      options = props.options,
      validationFn = props.validationFn,
      inputValue = props.inputValue,
      expressionInputClass = props.expressionInputClass;

  var _useState = useState(options),
      _useState2 = _slicedToArray(_useState, 2),
      inputItems = _useState2[0],
      setInputItems = _useState2[1];

  var _useState3 = useState(true),
      _useState4 = _slicedToArray(_useState3, 2),
      valid = _useState4[0],
      setValid = _useState4[1];

  var _useState5 = useState("string"),
      _useState6 = _slicedToArray(_useState5, 2),
      valueType = _useState6[0],
      setValueType = _useState6[1];

  var matchesAnInput = options.some(function (item) {
    return item.label === inputValue;
  });
  var textRef = useRef(null);
  useEffect(function () {
    setInputItems(options.filter(function (item) {
      return item.key.toLowerCase().startsWith(inputValue.toLowerCase());
    }));

    if (validationFn) {
      validationFn(inputValue) || matchesAnInput ? setValid(true) : setValid(false);
    }
  }, [inputValue]);

  var handleValueTypeChange = function handleValueTypeChange(val) {
    // check if the input value is present in any of the option
    var isPresentInOptions = options.find(function (option) {
      return option.label === val;
    });

    if (isPresentInOptions) {
      setValueType(isPresentInOptions.type);
    } else {
      setValueType("string"); // can also use typeof formattedInputValue but it will result in string anyways
    }
  };

  var stateReducer = function stateReducer(state, actionAndChanges) {
    var stateChangeTypes = useCombobox.stateChangeTypes;

    switch (actionAndChanges.type) {
      case stateChangeTypes.ItemClick:
      case stateChangeTypes.InputKeyDownEnter:
        // case useCombobox.stateChangeTypes.InputBlur:
        handleValueChange({
          target: {
            value: state.highlightedIndex > -1 ? actionAndChanges.changes.selectedItem.label : actionAndChanges.changes.inputValue || ""
          }
        });

        if (state.highlightedIndex > -1) {
          // handleValueTypeChange(actionAndChanges.changes.selectedItem.label)
          setValueType(actionAndChanges.changes.selectedItem.type);
        }

        return _objectSpread({}, actionAndChanges.changes, state.highlightedIndex > -1 && {
          inputValue: actionAndChanges.changes.selectedItem.key
        });

      default:
        return actionAndChanges.changes;
      // otherwise business as usual.
    }
  };

  var _useCombobox = useCombobox({
    items: inputItems,
    defaultIsOpen: true,
    initialIsOpen: true,
    initialHighlightedIndex: 0,
    stateReducer: stateReducer
  }),
      isOpen = _useCombobox.isOpen,
      openMenu = _useCombobox.openMenu,
      getMenuProps = _useCombobox.getMenuProps,
      getInputProps = _useCombobox.getInputProps,
      getComboboxProps = _useCombobox.getComboboxProps,
      highlightedIndex = _useCombobox.highlightedIndex,
      getItemProps = _useCombobox.getItemProps;

  var updateValueAndType = function updateValueAndType(e) {
    var val = e.target.value;
    handleValueChange(e);
    handleValueTypeChange(val);
  };

  var getInputWidth = function getInputWidth() {
    if (textRef.current) {
      return textRef.current.scrollWidth + 8;
    }

    return "10rem";
  };

  var showMenu = isOpen && !matchesAnInput && inputItems.length > 0;
  return React.createElement(React.Fragment, null, React.createElement("div", _extends({
    "data-type": "expression-input-root"
  }, getComboboxProps(), {
    className: expressionInputClass
  }), React.createElement("input", _extends({}, getInputProps({
    onChange: updateValueAndType,
    onKeyDown: onKeyDown,
    value: inputValue,
    ref: inputRef,
    placeholder: inputPlaceholder,
    onFocus: function onFocus() {
      return openMenu();
    }
  }), {
    style: {
      width: getInputWidth()
    },
    "data-valid": valid,
    "data-value-type": valueType
  })), React.createElement("div", {
    ref: textRef,
    style: textContentStyle
  }, inputValue || inputPlaceholder), showMenu && React.createElement("ul", _extends({
    "data-type": "expression-list"
  }, getMenuProps(), {
    style: menuStyles
  }), inputItems.map(function (item, index) {
    return React.createElement("li", _extends({
      "data-type": "expression-list-item",
      "data-item-type": item.type,
      style: highlightedIndex === index ? {
        backgroundColor: Neutral10.hex
      } : {},
      key: "".concat(item.key).concat(index)
    }, getItemProps({
      item: item,
      index: index
    })), React.createElement("span", null, item.label), React.createElement("span", null, item.keyLabel || ""));
  }))));
};

export default DropdownCombobox;