import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useRef, useState, useEffect } from "react";
import Exp from "./Expression";
import DownSelect from "./DownSelect";

var Drop = function Drop(props) {
  var placeholder = props.placeholder,
      EditorData = props.EditorData,
      node = props.node,
      _props$initialFocus = props.initialFocus,
      initialFocus = _props$initialFocus === void 0 ? false : _props$initialFocus,
      options = props.options,
      validationFn = props.validationFn,
      onChangeFn = props.onChangeFn,
      expressionRootClass = props.expressionRootClass,
      expressionInputClass = props.expressionInputClass;

  var _useState = useState(""),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      exp = _useState4[0],
      setExp = _useState4[1];

  var dropRef = useRef(null);
  useEffect(function () {
    if (dropRef.current && initialFocus) {
      dropRef.current.focus();
    }
  }, [dropRef.current]);
  var fnKeys = options.filter(function (fn) {
    return fn.type === "function";
  }).map(function (fn) {
    return fn.key;
  });

  var getValueType = function getValueType(value) {
    if (fnKeys.includes(value.toLowerCase())) return "fn";
    var listOption = options.find(function (option) {
      return option.label === value;
    });
    return listOption ? listOption.type : "string";
  };

  var getValueData = function getValueData(type, value) {
    if (type === "fn") {
      return options.find(function (f) {
        return f.key === value.toLowerCase();
      });
    }

    return value;
  };

  var handleValueChange = function handleValueChange(e) {
    var val = e.target.value;
    var valueType = getValueType(val);
    var valueData = getValueData(valueType, val);
    setValue(val);
    node.setValue({
      data: valueData,
      type: valueType
    }); // In case the input is a function, scaffold it's params

    if (valueType === "fn") setExp(true);
    if (onChangeFn) onChangeFn(EditorData);
  };

  var getNextNode = function getNextNode() {
    var currElement;

    if (dropRef.current) {
      currElement = dropRef.current.parentElement;
    } // if the present element has a next sibling, directly switch to next


    if (currElement.nextElementSibling) currElement = currElement.nextElementSibling; // this is when you want to skip the top levels and only switch in text fields
    else {
        while (!currElement.nextElementSibling) {
          currElement = currElement.parentElement;
          if (currElement.dataset.type === "knit-ui_extractor-root") return;
        }

        currElement = currElement.nextElementSibling;
      }
    if (currElement.dataset.type !== "expression-root") currElement = currElement.firstElementChild;
    return currElement;
  };

  var getPrevNode = function getPrevNode() {
    var currElement;

    if (dropRef.current) {
      currElement = dropRef.current.parentElement;
    } // if the present element has a next sibling, directly switch to next


    if (currElement.previousElementSibling) currElement = currElement.previousElementSibling;else {
      if (!currElement.previousElementSibling) currElement = currElement.parentElement;
    } // some transitions as per the element we arrive on

    while (currElement.dataset.type === "expression-root" && !initialFocus) {
      currElement = currElement.lastElementChild;
    }

    if (currElement.dataset.type === "expression-input-root") {
      currElement = currElement.firstElementChild;
    }

    return currElement;
  };

  var handleDir = function handleDir(e) {
    e.stopPropagation();
    var inputNode = dropRef.current;

    switch (e.keyCode) {
      case 39:
        // only  at last caret position
        if (inputNode.selectionStart !== inputNode.value.length) return;
        e.preventDefault();
        var nextNode = getNextNode();
        if (nextNode) nextNode.focus();
        break;

      case 37:
        // only when at caret position is 0
        if (inputNode.selectionStart !== 0) return;
        e.preventDefault();
        var prevNode = getPrevNode();
        if (prevNode) prevNode.focus();
        break;

      default:
        break;
    }
  };

  if (!exp) {
    return React.createElement(DownSelect, {
      inputRef: dropRef,
      inputPlaceholder: placeholder,
      options: options,
      onKeyDown: function onKeyDown(e) {
        return handleDir(e);
      },
      inputValue: value,
      validationFn: validationFn,
      expressionInputClass: expressionInputClass,
      handleValueChange: handleValueChange
    });
  }

  return React.createElement(Exp, {
    EditorData: EditorData,
    options: options,
    setExp: setExp,
    setValue: setValue,
    node: node,
    onChangeFn: onChangeFn,
    validationFn: validationFn,
    expressionRootClass: expressionRootClass,
    expressionInputClass: expressionInputClass,
    fname: value
  });
};

export default Drop;