import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useEffect, useRef } from "react";
import Drop from "./Dropdown";
import { TreeNode } from "./DataStructure";

var Expression = function Expression(props) {
  var fname = props.fname,
      node = props.node,
      EditorData = props.EditorData,
      setExp = props.setExp,
      options = props.options,
      setValue = props.setValue,
      onChangeFn = props.onChangeFn,
      _props$expressionRoot = props.expressionRootClass,
      expressionRootClass = _props$expressionRoot === void 0 ? "" : _props$expressionRoot,
      _props$expressionInpu = props.expressionInputClass,
      expressionInputClass = _props$expressionInpu === void 0 ? "" : _props$expressionInpu,
      validationFn = props.validationFn;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      rootFocus = _useState2[0],
      setRootFocus = _useState2[1];

  var expressionRoot = useRef(null); // find function metadata as per the given key.

  var fnData = options.find(function (f) {
    return f.key === fname.toLowerCase();
  });
  useEffect(function () {
    // create nodes for all children of the given function
    var _ref = fnData,
        params = _ref.params;
    params.forEach(function () {
      var refNode = new TreeNode({
        data: "",
        type: "string"
      });
      node.addChild(refNode);
    });
  }, []);

  var findNextNode = function findNextNode() {
    var initNode = expressionRoot.current.firstElementChild;
    if (initNode.dataset.type === "expression-root") return initNode;
    return initNode.firstElementChild;
  };

  var findPrevNode = function findPrevNode() {
    var initNode = expressionRoot.current;

    if (initNode.previousElementSibling) {
      initNode = initNode.previousElementSibling;

      while (initNode.lastElementChild && initNode.dataset.type === "expression-root") {
        initNode = initNode.lastElementChild;
      }

      initNode = initNode.firstElementChild;
    } else {
      if (initNode.parentElement.dataset.type === "expression-root") initNode = initNode.parentElement;
    }

    return initNode;
  };

  var handleKeyDown = function handleKeyDown(e) {
    e.stopPropagation(); // remove node when backspace is pressed and expression is in focus

    switch (e.keyCode) {
      case 8:
      case 46:
        if (rootFocus) {
          setExp(false);
          node.clearChildren();
          setValue("");
        }

        break;

      case 39:
        findNextNode().focus();
        break;

      case 37:
        findPrevNode().focus();
        break;

      default:
        return;
    }
  }; // Build the dom with dropdowns for the parameters of the function


  var PHDom = function PHDom() {
    var _ref2 = fnData,
        params = _ref2.params;
    return params.map(function (param, i) {
      return React.createElement(Drop, {
        EditorData: EditorData,
        key: i + param,
        onChangeFn: onChangeFn,
        options: options,
        expressionInputClass: expressionInputClass,
        expressionRootClass: expressionRootClass,
        node: node.children && node.children[i],
        validationFn: validationFn,
        initialFocus: i === 0,
        placeholder: param
      });
    });
  };

  if (fname) {
    return React.createElement("span", {
      ref: expressionRoot,
      className: expressionRootClass,
      "data-type": "expression-root",
      onKeyDown: handleKeyDown,
      onFocus: function onFocus() {
        return setRootFocus(true);
      },
      onBlur: function onBlur() {
        return setRootFocus(false);
      },
      tabIndex: 0,
      style: {
        display: "flex"
      }
    }, fnData.label, "(", PHDom(), ")");
  }

  return null;
};

export default Expression;