import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _extends from "@babel/runtime/helpers/extends";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useState, useEffect, useRef } from "react";
import { getIconSize } from "./utils";
import RenderInput from "./RenderInput";
import renderInputAddons from "./InputAddons";
import { IconBackground, InputWrapper, AddonIcon } from "./styledComponents";
var InputRef = React.forwardRef(function (props, ref) {
  var _useState = useState(props.value || ""),
      _useState2 = _slicedToArray(_useState, 2),
      currentValue = _useState2[0],
      setCurrentValue = _useState2[1];

  var _useState3 = useState(props.type === "password"),
      _useState4 = _slicedToArray(_useState3, 2),
      isPasswordField = _useState4[0],
      setIsPasswordField = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      isOverflow = _useState6[0],
      setIsOverflow = _useState6[1];

  useEffect(function () {
    // To update the current input value
    setCurrentValue(props.value);
  }, [props.value]);
  var currentRef = useRef(null);
  var customProps = {
    inputSize: props.inputSize,
    state: props.state
  };

  var handleChange = function handleChange(e) {
    // Handle onChange if provided and update the input value
    if (props.onChange) {
      props.onChange(e);
    }

    setCurrentValue(e.target.value);
  };

  var handleFocus = function handleFocus(e) {
    if (props.onFocus) {
      props.onFocus(e);
    }

    setIsOverflow(false);
  };

  var handleBlur = function handleBlur(e) {
    if (props.onBlur) {
      props.onBlur(e);
    }

    if (currentRef.current) {
      var input = currentRef.current.children[0];

      if (input.scrollWidth > input.clientWidth && !isOverflow) {
        setIsOverflow(true);
      } else if (input.scrollWidth <= input.clientWidth && isOverflow) {
        setIsOverflow(false);
      }
    }
  };

  var clearInput = function clearInput(e) {
    e.preventDefault();
    setCurrentValue("");
    var input = currentRef.current.children[0];

    if (!input) {
      return;
    } // Updating state programatically does not fire onChange event.
    // The following workaround is implemented to fire onChange.
    // Reference: https://github.com/facebook/react/issues/10135#issuecomment-401496776


    var _ref = Object.getOwnPropertyDescriptor(input, "value") || {},
        valueSetter = _ref.set;

    var prototype = Object.getPrototypeOf(input);

    var _ref2 = Object.getOwnPropertyDescriptor(prototype, "value") || {},
        prototypeValueSetter = _ref2.set;

    if (prototypeValueSetter && valueSetter !== prototypeValueSetter) {
      prototypeValueSetter.call(input, "");
    } else if (valueSetter) {
      valueSetter.call(input, "");
    }

    var event = new Event("input", {
      bubbles: true
    });
    input.dispatchEvent(event);
    input.focus();
  };

  var togglePasswordField = function togglePasswordField() {
    setIsPasswordField(function (prevState) {
      return !prevState;
    });
  };

  var getCurrentInputType = function getCurrentInputType() {
    // Get the input type. Useful while toggling password field.
    if (props.type === "number") {
      return "number";
    } else if (props.type === "textarea") {
      return "textarea";
    } else if (isPasswordField) {
      return "password";
    }

    return "default";
  }; // Implemented to save the effort of adding `getIconSize` on every Icon component


  var Icon = function Icon(iconProps) {
    return React.createElement(AddonIcon, _extends({
      size: getIconSize(props.inputSize)
    }, iconProps));
  };

  var InputElem = React.createElement(InputWrapper, {
    inputSize: props.inputSize,
    type: props.type,
    state: props.state,
    addonAfter: props.addonAfter,
    ref: currentRef,
    customProps: customProps,
    isOverflow: isOverflow
  }, React.createElement(RenderInput, _extends({}, props, {
    ref: ref,
    value: currentValue,
    onChange: handleChange,
    type: getCurrentInputType(),
    isOverflow: isOverflow,
    onBlur: handleBlur,
    onFocus: handleFocus
  })));
  var addonAfter = props.addonAfter;

  if (props.type === "search") {
    if (currentValue && currentValue.toString().length > 0) {
      addonAfter = React.createElement(IconBackground, {
        bgSize: getIconSize(props.inputSize)
      }, React.createElement(Icon, {
        type: "oClose",
        fill: "#000000",
        onMouseDown: clearInput,
        pointer: true
      }));
    } else {
      addonAfter = React.createElement(Icon, {
        type: "oSearch",
        fill: "#a6a6a6"
      });
    }
  } else if (props.type === "password") {
    if (isPasswordField) {
      addonAfter = React.createElement(Icon, {
        type: "oVisibility",
        fill: "#000000",
        onClick: togglePasswordField,
        pointer: true
      });
    } else {
      addonAfter = React.createElement(Icon, {
        type: "oVisibilityOff",
        fill: "#000000",
        onClick: togglePasswordField,
        pointer: true
      });
    }
  } else if (props.state === "success") {
    addonAfter = React.createElement(Icon, {
      type: "oCheckCircleOutline",
      fill: "#036600"
    });
  } else if (props.state === "warning") {
    addonAfter = React.createElement(Icon, {
      type: "oWarning",
      fill: "#FFC700"
    });
  } else if (props.state === "error") {
    addonAfter = React.createElement(Icon, {
      type: "oErrorOutline",
      fill: "#990000"
    });
  }

  return renderInputAddons(InputElem, _objectSpread({}, props, {
    addonAfter: addonAfter
  }));
});
export default InputRef;