import _extends from "@babel/runtime/helpers/extends";
import React, { useContext } from "react";
import styled, { css, ThemeContext } from "styled-components";
import _ from "lodash";
import Icon from "../Icon";
import InlineLabel from "./InlineLabel";
import { getFontColor, getBackgroundColor } from "./commonUtils";
var DEFAULT_COLOR_THEME = "neutral";
var INSET_BACKGROUND_COLOR = "#F7F7F7";
var typographySize = {
  small: 12,
  medium: 14,
  large: 14
};

var getFontSize = function getFontSize(props) {
  var typography = props.theme.knitui.typography,
      size = props.customProps.size;
  return typography[typographySize[size]].fontSize;
};

var geLineHeight = function geLineHeight(props) {
  var typography = props.theme.knitui.typography,
      size = props.customProps.size;
  return typography[typographySize[size]].lineHeight;
};

var getDarkenedBorderColor = function getDarkenedBorderColor(props) {
  return getBackgroundColor(props).set("hsl.l", "-0.2");
};

var showLeftIcon = function showLeftIcon(props) {
  var icons = props.customProps.icons;
  return icons && icons.left;
};

var showRightIcon = function showRightIcon(props) {
  var icons = props.customProps.icons;
  return icons && icons.right;
};

var verticalPadding = {
  small: 0,
  medium: 0.1,
  large: 0.3
};

var getIconPadding = function getIconPadding(size) {
  return size === "small" ? 0.2 : 0.4;
};

var getPadding = function getPadding(props) {
  var _props$customProps = props.customProps,
      size = _props$customProps.size,
      expanded = _props$customProps.expanded,
      outlined = _props$customProps.outlined,
      defaultBorderWidth = props.theme.knitui.defaultBorderWidth;
  var defaultHorizontalPadding = expanded ? 0.9 : 0.6;
  var left = defaultHorizontalPadding;
  var right = defaultHorizontalPadding;
  var vertical = verticalPadding[size];

  if (showLeftIcon(props)) {
    left = getIconPadding(size);
  }

  if (showRightIcon(props)) {
    right = getIconPadding(size);
  }

  return "".concat(vertical, "rem ").concat(right, "rem ").concat(vertical, "rem ").concat(left, "rem");
};

var getTextMargin = function getTextMargin(props) {
  var size = props.customProps.size;
  return size === "small" ? "0.2rem" : "0.4rem";
};

var getTextLeftMargin = function getTextLeftMargin(props) {
  return showLeftIcon(props) ? getTextMargin(props) : "0rem";
};

var getTextRightMargin = function getTextRightMargin(props) {
  return showRightIcon(props) ? getTextMargin(props) : "0rem";
};

var getBorder = function getBorder(props) {
  var outlined = props.customProps.outlined,
      defaultBorderWidth = props.theme.knitui.defaultBorderWidth;
  var borderColor = outlined ? getDarkenedBorderColor(props) : "transparent";
  return "".concat(defaultBorderWidth, "rem solid ").concat(borderColor);
};

var getBorderRadius = function getBorderRadius(props) {
  var rounded = props.customProps.rounded;
  return rounded ? "999px" : "0.2rem";
};

var getBoxShadow = function getBoxShadow(props) {
  var shades = props.theme.knitui.shades,
      focus = props.customProps.focus;
  return focus ? "0rem 0rem 0.2rem ".concat(shades.blue50) : "none";
};

var getInsetStyles = function getInsetStyles(props) {
  var insetColor = props.insetColor;
  return insetColor ? css(["&::before{content:\"\";position:absolute;top:0;bottom:0;left:0;width:0.3rem;background:", ";border-radius:0.2rem 0 0 0.2rem;}"], insetColor) : "";
};

var LabelContainer =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "Label__LabelContainer",
  componentId: "sc-1n9e7xv-0"
})(["display:inline-flex;position:relative;"]);
var StyledDiv =
/*#__PURE__*/
styled.div.withConfig({
  displayName: "Label__StyledDiv",
  componentId: "sc-1n9e7xv-1"
})(["display:inline-flex;align-items:center;padding:", ";background-color:", ";color:", ";font-size:", ";line-height:", ";border-radius:", ";border:", ";box-sizing:border-box;box-shadow:", ";overflow:hidden;", ""], function (props) {
  return getPadding(props);
}, function (props) {
  return getBackgroundColor(props);
}, function (props) {
  return getFontColor(props);
}, function (props) {
  return "".concat(getFontSize(props), "rem");
}, function (props) {
  return "".concat(geLineHeight(props), "rem");
}, function (props) {
  return getBorderRadius(props);
}, function (props) {
  return getBorder(props);
}, function (props) {
  return getBoxShadow(props);
}, function (props) {
  return getInsetStyles(props);
});
var StyledTextSpan =
/*#__PURE__*/
styled.span.withConfig({
  displayName: "Label__StyledTextSpan",
  componentId: "sc-1n9e7xv-2"
})(["margin:0rem ", " 0rem ", ";"], function (props) {
  return getTextRightMargin(props);
}, function (props) {
  return getTextLeftMargin(props);
});

var Label = function Label(props) {
  var labelPropKeys = ["size", "rounded", "outlined", "icons", "focus", "insetColor", "text", "expanded", "colorPreset", "customColor", "customFontColor"];

  var labelProps = _.pick(props, labelPropKeys);

  var otherProps = _.omit(props, labelPropKeys);

  var text = labelProps.text,
      insetColor = labelProps.insetColor,
      icons = labelProps.icons;
  /**
   * Styled Component theme should be needed here, because getFontColor take theme
   * as argument
   */

  var theme = useContext(ThemeContext);
  /**
   * If an insetColor is specified, the background color should be set to a default unless
   * explicitly provided through customColor
   */

  if (insetColor) {
    labelProps.customColor = labelProps.customColor || INSET_BACKGROUND_COLOR;
  }

  var scProps = {
    theme: theme,
    customProps: labelProps
  };

  var renderLeftIcon = function renderLeftIcon() {
    if (!showLeftIcon(scProps)) {
      return null;
    }

    if (_.isString(icons.left)) {
      return React.createElement(Icon, {
        fill: getFontColor(scProps),
        type: icons.left
      });
    }

    return icons.left;
  };

  var renderRightIcon = function renderRightIcon() {
    if (!showRightIcon(scProps)) {
      return null;
    }

    if (_.isString(icons.right)) {
      return React.createElement(Icon, {
        fill: getFontColor(scProps),
        type: icons.right
      });
    }

    return icons.right;
  }; //For styled components, we separate the props that are to be loaded on the DOM


  return React.createElement(LabelContainer, null, React.createElement(StyledDiv, _extends({}, scProps, otherProps, {
    insetColor: insetColor
  }), renderLeftIcon(), React.createElement(StyledTextSpan, scProps, text), renderRightIcon()));
};

Label.defaultProps = {
  expanded: false,
  size: "medium",
  rounded: false,
  outlined: false,
  colorPreset: DEFAULT_COLOR_THEME,
  focus: false
};
Label.Inline = InlineLabel;
export default Label;