import React, { useContext } from "react";
import styled from "styled-components";
import Dialog from "rc-dialog";
import { Body, Footer, Header, Panel } from "./wrappers";
import "rc-dialog/assets/index.css";
import { ThemeContext } from "styled-components";
import { Modal, LeftPanelModal, RightPanelModal, BottomPanelModal } from "./variants/index";
import Icon from "../Icon";
import { sizeToWidth } from "./helpers"; // Animation related

var appearDuration = 250;
var transitionName = "modal";
var maskTransitionName = "modalMask";
var maskDuration = 100;
var modalEnterTransitionPath = "cubic-bezier(0, 0, 0, 1)";
var modalLeaveTransitionPath = "cubic-bezier(1, 0, 1, 1)";
var animationDelay = "50ms"; // Animations on leave are not working for rc-dialog, this happens only when
// styiling the Dialog using styled components. It is probably the case that
// the Dialog component is being re-created on close, causing the previous
// stored ref to be lost

var StyledDialog =
/*#__PURE__*/
styled(Dialog).withConfig({
  displayName: "ModalWrapper__StyledDialog",
  componentId: "u6sukv-0"
})([".rc-dialog-body{padding:0;height:auto;max-height:", ";min-height:", ";}width:", " !important;margin:30px auto !important;.rc-dialog-content{border-radius:", ";}.rc-dialog-close{right:-1rem;top:-1rem;opacity:unset;padding:0.15rem;line-height:0;background-color:", ";border-radius:999px;svg{fill:", ";}}&.", "-appear,&.", "-enter{opacity:0;transform:scale(0.9);}&.", "-appear.", "-appear-active,&.", "-enter.", "-enter-active{opacity:1;transform:scale(1);transition:opacity ", "ms ", " ", ",transform ", "ms ", " ", ";}&.", "-leave{opacity:1;transform:scale(1);}&.", "-leave.", "-leave-active{opacity:0;transform:scale(0.9);transition:opacity ", "ms ", ",transform ", "ms ", ";}&.", "-appear,&.", "-enter{opacity:0;}&.", "-appear.", "-appear-active,&.", "-enter.", "-enter-active{opacity:1;transition:opacity ", "ms ease-out;}&.", "-leave{opacity:1;}&.", "-leave.", "-leave-active{opacity:0;transition:opacity ", "ms ease-out;}"], function (_ref) {
  var knitui = _ref.theme.knitui;
  return "calc(100vh - ".concat(knitui.modalMaxContentHeightOffset, "rem)");
}, function (_ref2) {
  var knitui = _ref2.theme.knitui;
  return "".concat(knitui.modalMinHeight, "rem");
}, function (_ref3) {
  var size = _ref3.customProps.size;
  return sizeToWidth[size];
}, function (_ref4) {
  var knitui = _ref4.theme.knitui;
  return knitui.modalBorderRadius;
}, function (_ref5) {
  var knitui = _ref5.theme.knitui;
  return knitui.chromaPalette.Neutral50;
}, function (_ref6) {
  var knitui = _ref6.theme.knitui;
  return knitui.chromaPalette.Neutral20;
}, transitionName, transitionName, transitionName, transitionName, transitionName, transitionName, appearDuration, modalEnterTransitionPath, animationDelay, appearDuration, modalEnterTransitionPath, animationDelay, transitionName, transitionName, transitionName, appearDuration, modalLeaveTransitionPath, appearDuration, modalLeaveTransitionPath, maskTransitionName, maskTransitionName, maskTransitionName, maskTransitionName, maskTransitionName, maskTransitionName, maskDuration, maskTransitionName, maskTransitionName, maskTransitionName, maskDuration);
/**
 * The external interface for the modal
 */

var ModalWrapper = function ModalWrapper(_ref7) {
  var _ref7$size = _ref7.size,
      size = _ref7$size === void 0 ? "medium" : _ref7$size,
      getContainer = _ref7.getContainer,
      visible = _ref7.visible,
      onClose = _ref7.onClose,
      panel = _ref7.panel,
      destroyOnClose = _ref7.destroyOnClose,
      className = _ref7.className,
      style = _ref7.style,
      padding = _ref7.padding,
      children = _ref7.children;
  var ModalProxy = {
    left: LeftPanelModal,
    right: RightPanelModal,
    bottom: BottomPanelModal
  };
  var themeContext = useContext(ThemeContext);
  var knitui = themeContext.knitui;
  var typographySize = knitui.modalTitleTypographySize;
  var lineHeight = knitui.typography[typographySize].lineHeight;
  var verticalPadding = knitui.modalHeaderPadding.vertical;
  var headerHeight = lineHeight + 2 * verticalPadding;
  var totalOffset = knitui.modalMaxContentHeightOffset + headerHeight;
  var maxContentHeight = "calc(100vh - ".concat(totalOffset, "rem)");
  var minContentHeight = "".concat(knitui.modalMinHeight - headerHeight, "rem");
  var ModalToRender = panel ? ModalProxy[panel] : Modal;
  return React.createElement(StyledDialog, {
    customProps: {
      size: size
    },
    getContainer: getContainer,
    visible: visible,
    onClose: onClose,
    closeIcon: React.createElement(Icon, {
      type: "oClear"
    }),
    destroyOnClose: destroyOnClose,
    transitionName: transitionName,
    maskTransitionName: maskTransitionName,
    className: className,
    style: style
  }, React.createElement(ModalToRender, {
    padding: padding,
    maxContentHeight: maxContentHeight,
    minContentHeight: minContentHeight
  }, children));
};

ModalWrapper.defaultProps = {
  size: "medium",
  padding: {
    vertical: "2.8rem",
    horizontal: "2.1rem"
  },
  visible: false,
  destroyOnClose: false
};
ModalWrapper.Body = Body;
ModalWrapper.Footer = Footer;
ModalWrapper.Header = Header;
ModalWrapper.Panel = Panel;
export default ModalWrapper;