import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { Children, cloneElement } from "react";
import Avatar from "../../Avatar";
import Icon from "../../Icon";
import Label from "../../Label";
import { FlexWrapper, OptionItemWrapper, OptionWrapper, StyledDivider } from "./Option.styles";
import OptionGroup from "./OptionGroup";
import OptionText from "./OptionText";

var Option = function Option(props) {
  var value = props.value,
      customStyles = props.customStyles,
      onClick = props.onClick,
      children = props.children,
      selected = props.selected,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      rest = _objectWithoutProperties(props, ["value", "customStyles", "onClick", "children", "selected", "disabled"]); // Pass disabled props to all children


  var updatedChildren = Children.map(children, function (child) {
    return cloneElement(child, {
      disabled: disabled
    });
  }); // Filter children based on their alignment

  var rightChildren = Children.toArray(updatedChildren).filter(function (comp) {
    return comp.props.align === "right";
  });
  var leftChildren = Children.toArray(updatedChildren).filter(function (comp) {
    return comp.props.align !== "right";
  });
  return React.createElement(OptionWrapper, _extends({
    onClick: onClick ? function (e) {
      return onClick(e, value);
    } : function () {
      return null;
    },
    style: customStyles,
    isDisabled: disabled,
    selected: selected
  }, rest), !children && React.createElement(Option.Text, null, value), React.createElement(FlexWrapper, null, leftChildren), React.createElement(FlexWrapper, {
    align: "right"
  }, rightChildren, selected && React.createElement(Option.Icon, {
    type: "oCheck",
    align: "right"
  })));
}; // Wrap all option sub-components in a common wrapper and pass all props to the corresponding component


Option.Icon = OptionItemWrapper(Icon, {});
Option.Text = OptionItemWrapper(OptionText, {});
Option.Tag = OptionItemWrapper(Label, {});
Option.Avatar = OptionItemWrapper(Avatar, {
  alignStart: true
});
Option.Group = OptionGroup;
Option.Divider = StyledDivider;
export default Option;