import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import React, { useState, cloneElement } from "react";
import _ from "lodash";
import Radio from "./Radio";

var renderRadio = function renderRadio(props, value, setValue) {
  var propsToPass = _.omit(props, ["children", "defaultValue"]);

  var Radios = props.children || React.createElement(React.Fragment, null);
  if (!Array.isArray(Radios)) Radios = React.Children.toArray(Radios);
  return Radios.map(function (radio, index) {
    return cloneElement(radio, _objectSpread({
      setValue: setValue,
      style: props.style,
      key: index,
      checked: value === radio.props.value
    }, propsToPass));
  });
};

var getDefaultValue = function getDefaultValue(radios) {
  var child = React.Children.count(radios);

  if (child < 2) {
    // Optionally throw error if need be
    console.error("Add 2 or more Radio Items to the Group");
  }

  switch (true) {
    case child > 1:
      var len = radios.length - 1;

      for (var radio in radios) {
        if (radios[len - Number(radio)].props.checked) {
          return radios[len - Number(radio)].props.value;
        }
      }

      return null;

    case child === 1:
      /**
       * In some cases if child is rendered using <RadioGroup>{[].map(val => val)}</RadioGroup>
       * it always pass structure as array. We have to detect the structure first & then manipulate
       */
      var singleRadio = Array.isArray(radios) ? radios[0] : radios;
      return singleRadio.props.checked ? singleRadio.props.value : null;

    default:
      return null;
  }
};

var RadioGroup = function RadioGroup(props) {
  var radioValue = getDefaultValue(props.children);

  var _useState = useState(radioValue || props.defaultValue),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  return React.createElement(React.Fragment, null, renderRadio(props, value, setValue));
};

RadioGroup.defaultProps = {
  size: "medium"
};
RadioGroup.Item = Radio;
export default RadioGroup;