import _extends from "@babel/runtime/helpers/extends";
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from "react";
import { StyledRadioRoot, StyledRadioInput, StyledRadioInner } from "./styledRadio";

var RadioWrapper = function RadioWrapper(props) {
  var prefixCls = props.prefixCls,
      className = props.className,
      style = props.style,
      size = props.size,
      disabled = props.disabled,
      readOnly = props.readOnly,
      tabIndex = props.tabIndex,
      onClick = props.onClick,
      onFocus = props.onFocus,
      onBlur = props.onBlur,
      autoFocus = props.autoFocus,
      onChange = props.onChange,
      value = props.value,
      checked = props.checked,
      setValue = props.setValue,
      others = _objectWithoutProperties(props, ["prefixCls", "className", "style", "size", "disabled", "readOnly", "tabIndex", "onClick", "onFocus", "onBlur", "autoFocus", "onChange", "value", "checked", "setValue"]);

  var handleChange = function handleChange(e) {
    if (props.disabled) {
      return;
    }

    if (setValue) {
      setValue(value);
    }

    if (onChange) {
      onChange({
        target: _objectSpread({}, props, {
          checked: e.target.checked
        }),
        stopPropagation: function stopPropagation() {
          e.stopPropagation();
        },
        preventDefault: function preventDefault() {
          e.preventDefault();
        },
        nativeEvent: e.nativeEvent
      });
    }
  }; // https://github.com/react-component/checkbox/blob/3efbcecbe41533c90a0844d836adbc28c8b0a7ff/src/Checkbox.jsx#L116
  // Pass aria and data, props, role the the created element


  var globalProps = Object.keys(others).reduce(function (prev, key) {
    if (key.substr(0, 5) === "aria-" || key.substr(0, 5) === "data-" || key === "role") {
      prev[key] = others[key];
    }

    return prev;
  }, {});
  var checkedClass = checked ? "".concat(prefixCls, "-checked") : "";
  var disabledClass = props.disabled ? "".concat(prefixCls, "-disabled") : "";
  var rootClass = "".concat(prefixCls, " ").concat(className || "", " ").concat(checkedClass, " ").concat(disabledClass);
  var styleProps = {
    size: size,
    disabled: disabled
  };
  return React.createElement(StyledRadioRoot, _extends({
    className: rootClass
  }, styleProps, {
    style: style
  }), React.createElement(StyledRadioInput, _extends({
    name: name,
    type: "radio",
    readOnly: readOnly,
    disabled: disabled,
    tabIndex: tabIndex,
    className: "".concat(prefixCls, "-input"),
    checked: checked,
    onClick: onClick,
    onFocus: onFocus,
    onBlur: onBlur,
    onChange: handleChange,
    autoFocus: autoFocus,
    value: value
  }, globalProps)), React.createElement(StyledRadioInner, _extends({}, styleProps, {
    className: "".concat(prefixCls, "-inner")
  })));
};

RadioWrapper.defaultProps = {
  prefixCls: "knit-radio",
  className: "",
  style: {},
  size: "medium",
  onFocus: function onFocus() {},
  onBlur: function onBlur() {},
  onChange: function onChange() {}
};
export default RadioWrapper;