import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { Children, useState, useEffect, useRef } from "react";
import arrayMove from "array-move";
import { Icon } from "..";
import { TabsList } from "./TabsList";
import { GlobalStyle, ButtonWrapper, TabsWrapper, TabsPanelWrapper, OverflowWrapper, BlurElement, IconWrapper, TabPanel, TabContentWrapper } from "./styles";
import { getWidthFromRef, DEFAULT_COLOR } from "./utils";

var getActiveKeyIndex = function getActiveKeyIndex(childrenArray, activeKey) {
  return childrenArray.findIndex(function (child) {
    return child.props.tabKey === activeKey;
  });
};

var onScroll = function onScroll(listRef, activeNxtRef, itemRef, activePrevRef, setActiveTabFlags, setScrollFlags) {
  var current = listRef.current;

  if (!current) {
    return;
  }

  if (activeNxtRef.current && itemRef.current && current.offsetLeft + current.scrollLeft + itemRef.current.clientWidth >= activeNxtRef.current.offsetLeft) {
    setActiveTabFlags({
      right: false,
      left: true
    });
  } else if (activePrevRef.current && itemRef.current && current.offsetLeft + current.scrollLeft + current.clientWidth <= activePrevRef.current.offsetLeft + activePrevRef.current.clientWidth + itemRef.current.clientWidth) {
    setActiveTabFlags({
      right: true,
      left: false
    });
  } else {
    setActiveTabFlags({
      right: false,
      left: false
    });
  }

  var leftSideScroll = current.scrollLeft > 0;
  var rightSideScroll = current.scrollLeft !== current.scrollWidth - current.offsetWidth;
  var scrollFlags = {
    leftSideScroll: leftSideScroll,
    rightSideScroll: rightSideScroll
  };
  setScrollFlags(scrollFlags);
};

var Tabs = function Tabs(_ref) {
  var children = _ref.children,
      tabProps = _objectWithoutProperties(_ref, ["children"]);

  var childrenArrayProps = Children.toArray(children);
  var firstTab = childrenArrayProps[0] && childrenArrayProps[0].props.tabKey;
  var internalState = useState(tabProps.defaultActiveKey || firstTab);
  var _tabProps$activeKey = tabProps.activeKey,
      activeKey = _tabProps$activeKey === void 0 ? internalState[0] : _tabProps$activeKey,
      _tabProps$onChange = tabProps.onChange,
      onChange = _tabProps$onChange === void 0 ? internalState[1] : _tabProps$onChange,
      onAddTab = tabProps.onAddTab,
      onOrderChange = tabProps.onOrderChange,
      _tabProps$pressDelay = tabProps.pressDelay,
      pressDelay = _tabProps$pressDelay === void 0 ? 100 : _tabProps$pressDelay,
      _tabProps$hideTabCont = tabProps.hideTabContent,
      hideTabContent = _tabProps$hideTabCont === void 0 ? false : _tabProps$hideTabCont,
      _tabProps$useDragHand = tabProps.useDragHandle,
      useDragHandle = _tabProps$useDragHand === void 0 ? false : _tabProps$useDragHand,
      _tabProps$dragHandleE = tabProps.dragHandleElement,
      dragHandleElement = _tabProps$dragHandleE === void 0 ? null : _tabProps$dragHandleE,
      _tabProps$readOnly = tabProps.readOnly,
      readOnly = _tabProps$readOnly === void 0 ? false : _tabProps$readOnly,
      _tabProps$hideAdd = tabProps.hideAdd,
      hideAdd = _tabProps$hideAdd === void 0 ? false : _tabProps$hideAdd,
      addButtonElement = tabProps.addButtonElement,
      _tabProps$customColor = tabProps.customColor,
      customColor = _tabProps$customColor === void 0 ? DEFAULT_COLOR : _tabProps$customColor,
      _tabProps$lockOffset = tabProps.lockOffset,
      lockOffset = _tabProps$lockOffset === void 0 ? 100 : _tabProps$lockOffset;

  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      childrenArray = _useState2[0],
      setChildrenArray = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      activeKeyIndex = _useState4[0],
      setActiveKeyIndex = _useState4[1];

  var _useState5 = useState({
    leftSideScroll: false,
    rightSideScroll: false
  }),
      _useState6 = _slicedToArray(_useState5, 2),
      scrollFlags = _useState6[0],
      setScrollFlags = _useState6[1];

  var _useState7 = useState({
    right: false,
    left: false
  }),
      _useState8 = _slicedToArray(_useState7, 2),
      activeTabFlags = _useState8[0],
      setActiveTabFlags = _useState8[1]; // ref for main scrollable list container


  var listRef = useRef(null); // ref for active tab

  var itemRef = useRef(null); // ref for tab after active tab

  var activeNxtRef = useRef(null); // ref for tab before active tab

  var activePrevRef = useRef(null); // ref for left-arrow wrapper, instead of hard code width better to use ref.

  var leftArrowRef = useRef(null); // ref for right-arrow wrapper, instead of hard code width better to use ref.

  var rightArrowRef = useRef(null);
  useEffect(function () {
    var current = listRef.current;
    current && current.addEventListener("scroll", function () {
      return onScroll(listRef, activeNxtRef, itemRef, activePrevRef, setActiveTabFlags, setScrollFlags);
    });
  }, []);
  useEffect(function () {
    setChildrenArray(childrenArrayProps);
  }, [children]);
  useEffect(function () {
    var index = getActiveKeyIndex(childrenArray, activeKey);
    setActiveKeyIndex(index);
  }, [childrenArray, activeKey]);
  useEffect(function () {
    onScroll(listRef, activeNxtRef, itemRef, activePrevRef, setActiveTabFlags, setScrollFlags);
  }, [activeKeyIndex]);

  var getTabsContent = function getTabsContent() {
    return childrenArray.map(function (child) {
      var key = child.props.tabKey;
      var active = key === activeKey;
      if (active) return child.props.children;
      return React.createElement("div", {
        key: key
      });
    });
  };

  var onSortEnd = function onSortEnd(_ref2) {
    var oldIndex = _ref2.oldIndex,
        newIndex = _ref2.newIndex;
    var newChildren = arrayMove(childrenArray, oldIndex, newIndex);
    setChildrenArray(newChildren);
    onOrderChange && onOrderChange({
      oldIndex: oldIndex,
      newIndex: newIndex
    });
    document.body.style.cursor = "default";
  };

  var onSortStart = function onSortStart() {
    document.body.style.cursor = "grabbing";
  };

  var handleScrollRight = function handleScrollRight() {
    var list = listRef.current;

    if (list) {
      var distance = list.clientWidth + list.scrollLeft - 140 * 2;
      list.scrollTo({
        behavior: "smooth",
        left: distance
      });
    }
  };

  var handleScrollLeft = function handleScrollLeft() {
    var list = listRef.current;

    if (list) {
      var distance = list.scrollLeft + 140 * 2 - list.clientWidth;
      list.scrollTo({
        behavior: "smooth",
        left: distance
      });
    }
  };

  var AddButtonElement = addButtonElement && React.cloneElement(addButtonElement, {
    onClick: onAddTab,
    disabled: readOnly
  });
  var showRightArrow = scrollFlags.rightSideScroll;
  var showLeftArrow = scrollFlags.leftSideScroll;
  var showRightBlur = showRightArrow && !activeTabFlags.right;
  var showLeftBlur = showLeftArrow && !activeTabFlags.left;
  var showActiveLeftBlur = showLeftArrow && activeTabFlags.left;
  var showActiveRightBlur = showRightArrow && activeTabFlags.right;
  return React.createElement(React.Fragment, null, React.createElement(GlobalStyle, {
    customColor: customColor
  }), React.createElement(TabsWrapper, {
    hideTabContent: hideTabContent
  }, React.createElement(TabsPanelWrapper, {
    customColor: customColor
  }, React.createElement(OverflowWrapper, {
    activeTabRef: itemRef
  }, React.createElement(IconWrapper, {
    ref: leftArrowRef,
    visible: showLeftArrow,
    onClick: handleScrollLeft,
    customColor: customColor
  }, React.createElement(Icon, {
    type: "oKeyboardArrowLeft",
    size: "18px",
    fill: "#000000"
  })), React.createElement(BlurElement, {
    visible: showLeftBlur,
    dir: "left",
    style: {
      left: getWidthFromRef(leftArrowRef)
    },
    customColor: customColor
  }), React.createElement(BlurElement, {
    visible: showActiveLeftBlur,
    dir: "left",
    style: {
      left: getWidthFromRef(leftArrowRef) + getWidthFromRef(itemRef)
    },
    customColor: customColor
  }), React.createElement(TabsList, {
    listRef: listRef,
    dragHandleElement: dragHandleElement,
    dragHandle: useDragHandle,
    useDragHandle: useDragHandle,
    shouldCancelStart: function shouldCancelStart() {
      return readOnly;
    },
    readOnly: readOnly,
    items: childrenArray,
    activeKey: activeKey,
    activeKeyIndex: activeKeyIndex,
    onSortStart: onSortStart,
    onSortEnd: onSortEnd,
    axis: "x",
    lockAxis: "x",
    pressDelay: pressDelay,
    onChange: onChange,
    activeTabFlags: activeTabFlags,
    itemRef: itemRef,
    activeNxtRef: activeNxtRef,
    activePrevRef: activePrevRef,
    customColor: customColor,
    helperClass: "knitui-tabs-helper",
    lockToContainerEdges: true,
    lockOffset: lockOffset
  }), React.createElement(BlurElement, {
    visible: showActiveRightBlur,
    dir: "right",
    style: {
      right: getWidthFromRef(rightArrowRef) + getWidthFromRef(itemRef)
    },
    customColor: customColor
  }), React.createElement(BlurElement, {
    visible: showRightBlur,
    dir: "right",
    style: {
      right: getWidthFromRef(rightArrowRef)
    },
    customColor: customColor
  }), React.createElement(IconWrapper, {
    ref: rightArrowRef,
    visible: showRightArrow,
    onClick: handleScrollRight,
    customColor: customColor
  }, React.createElement(Icon, {
    type: "oKeyboardArrowRight",
    size: "18px",
    fill: "#000000"
  }))), !hideAdd && (AddButtonElement || React.createElement(ButtonWrapper, {
    disabled: readOnly,
    onClick: onAddTab,
    icon: "oAdd",
    bare: true,
    customColor: "#000000",
    bgColor: customColor
  }))), !hideTabContent && React.createElement(TabContentWrapper, null, getTabsContent())));
};

Tabs.TabPanel = TabPanel;
export default Tabs;