"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withProps = withProps;
exports.getOSName = exports.getThemeLineHeight = exports.getThemeFontSize = exports.getColorOfLightness = exports.getThemeColor = exports.parseColorPreset = exports.parseCustomColor = exports.getFontColor = exports.getHoverBackgroundColor = exports.getHoverFontColor = exports.isLightColor = exports.hslToChroma = exports.insertIf = void 0;

var _chromaJs = _interopRequireDefault(require("chroma-js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var insertIf = function insertIf() {
  var obj = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var condition = arguments.length > 1 ? arguments[1] : undefined;
  var isArray = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  if (condition) {
    return obj;
  }

  if (isArray) {
    return [];
  }

  return {};
}; // https://github.com/styled-components/styled-components/issues/630


exports.insertIf = insertIf;

function withProps() {
  return function (fn) {
    return fn;
  };
} // Color utils

/**
 * Used for parsing hsl color values defined in [h, s, l] format
 * into a chroma object
 */


var hslToChroma = function hslToChroma(hsl) {
  var _hsl = _slicedToArray(hsl, 3),
      h = _hsl[0],
      s = _hsl[1],
      l = _hsl[2];

  return _chromaJs.default.hsl(h, s / 100, l / 100);
};
/**
 * Checks if the color is light or darks based on its L value in
 * the HSL color scale.
 * @param color A chroma color instance
 */


exports.hslToChroma = hslToChroma;

var isLightColor = function isLightColor(color) {
  return color.get("hsl.l") >= 0.5;
};
/**
 * Returns font color of updated lightness on hover
 * @param color A chroma color instance
 */


exports.isLightColor = isLightColor;

var getHoverFontColor = function getHoverFontColor(color) {
  return isLightColor(color) ? color.set("hsl.l", "-0.3") : color.set("hsl.l", "+0.3");
};
/**
 * Returns background color of updated lightness on hover
 * @param color A chroma color instance
 */


exports.getHoverFontColor = getHoverFontColor;

var getHoverBackgroundColor = function getHoverBackgroundColor(color) {
  return isLightColor(color) ? color.set("hsl.l", "-0.1") : color.set("hsl.l", "+0.1");
};
/**
 * Determines the appropriate font color based on the background color.
 */


exports.getHoverBackgroundColor = getHoverBackgroundColor;

var getFontColor = function getFontColor(theme, backGroundColor) {
  return isLightColor(backGroundColor) ? theme.chromaPalette.Neutral90 : theme.chromaPalette.Neutral0;
};

exports.getFontColor = getFontColor;

var createParsedColorTheme = function createParsedColorTheme(theme, backgroundColor) {
  return {
    background: backgroundColor,
    font: getFontColor(theme, backgroundColor)
  };
};
/**
 * Creates an object with background and font properties initialized
 * with appropriate chroma colors.
 * @param backGroundColor A plain CSS color string
 */


var parseCustomColor = function parseCustomColor(theme, customColor) {
  if (!(_chromaJs.default.valid(customColor) || _typeof(customColor) === "object" && _chromaJs.default.valid(customColor.color) && _chromaJs.default.valid(customColor.secondaryColor))) {
    throw new Error("Provided color theme contains invalid color values");
  }

  if (_typeof(customColor) === "object") {
    return {
      font: (0, _chromaJs.default)(customColor.secondaryColor),
      background: (0, _chromaJs.default)(customColor.color)
    };
  }

  customColor = (0, _chromaJs.default)(customColor);
  return createParsedColorTheme(theme, customColor);
};
/**
 * Creates an object with background and font properties initialized
 * with appropriate chroma colors.
 * @param backGroundColor One of the predefined preset values
 */


exports.parseCustomColor = parseCustomColor;

var parseColorPreset = function parseColorPreset(theme, backgroundColor) {
  backgroundColor = theme.secondaryPalette[backgroundColor];
  return createParsedColorTheme(theme, backgroundColor);
};
/**
 * Get color from Styled Component Props
 */


exports.parseColorPreset = parseColorPreset;

var getThemeColor = function getThemeColor(props, color) {
  var chromaPalette = props.theme.knitui.chromaPalette;
  return chromaPalette[color].hex();
};
/**
 * Get different lightness of passed color, range of lightness is between 0 to 100
 */


exports.getThemeColor = getThemeColor;

var getColorOfLightness = function getColorOfLightness(props, color, lightness) {
  var chromaPalette = props.theme.knitui.chromaPalette;
  var computedColor;
  if (chromaPalette.hasOwnProperty(color)) computedColor = chromaPalette[color].set("hsl.l", lightness / 100).hex();else if (_chromaJs.default.valid(color)) computedColor = (0, _chromaJs.default)(color).set("hsl.l", lightness / 100).hex();else computedColor = color;
  return computedColor;
};
/**
 * Get font-size from Styled Component Props
 */


exports.getColorOfLightness = getColorOfLightness;

var getThemeFontSize = function getThemeFontSize(props, size) {
  var knitui = props.theme.knitui;
  return knitui.typography[size].fontSize;
};
/**
 * Get line-height from Styled Component Props
 */


exports.getThemeFontSize = getThemeFontSize;

var getThemeLineHeight = function getThemeLineHeight(props, size) {
  var knitui = props.theme.knitui;
  return knitui.typography[size].lineHeight;
};
/**
 * Get OS of current platform
 */


exports.getThemeLineHeight = getThemeLineHeight;

var getOSName = function getOSName() {
  var platform = window.navigator.platform;
  var userAgent = window.navigator.userAgent;
  var macOSList = ["Macintosh", "MacIntel", "MacPPC", "Mac68K"];
  var windowOSList = ["Windows", "Win16", "Win32", "WinCE"];
  var iOSList = ["iPhone", "iPad", "iPod"];
  var os;

  if (macOSList.includes(platform)) {
    os = "MacOS";
  } else if (windowOSList.includes(platform)) {
    os = "Windows";
  } else if (iOSList.includes(platform)) {
    os = "iOS";
  } else if (/Android/.test(userAgent)) {
    os = "Android";
  } else if (/Linux/.test(userAgent)) {
    os = "Linux";
  }

  return os;
};

exports.getOSName = getOSName;