"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _StyledAlert = require("./StyledAlert");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var defaultIcons = {
  neutral: "oInfo",
  unsaved: "oInfo",
  danger: "oError",
  warning: "oWarning",
  success: "oCheckCircle"
};

var getClassName = function getClassName(prfxCls, suffix) {
  return prfxCls ? prfxCls + suffix : "";
};

var renderIcon = function renderIcon(scProps) {
  var _scProps$customProps = scProps.customProps,
      prefixClassName = _scProps$customProps.prefixClassName,
      image = _scProps$customProps.image,
      icon = _scProps$customProps.icon,
      type = _scProps$customProps.type;
  scProps.className = getClassName(prefixClassName, "-knit-alert-icon");
  if (image) return _react.default.createElement(_StyledAlert.StyledAlertPicture, _extends({}, scProps, {
    src: image
  }));
  if (icon) return _react.default.createElement(_StyledAlert.StyledAlertIcon, _extends({}, scProps, {
    type: icon
  }));
  return _react.default.createElement(_StyledAlert.StyledAlertIcon, _extends({}, scProps, {
    type: defaultIcons[type]
  }));
};

var renderActions = function renderActions(scProps) {
  var _scProps$customProps2 = scProps.customProps,
      actions = _scProps$customProps2.actions,
      prfxCls = _scProps$customProps2.prefixClassName,
      type = _scProps$customProps2.type,
      alertKey = _scProps$customProps2.alertKey;

  if (Array.isArray(actions) && actions.length == 0) {
    return null;
  } // Only pick top 2 actions in case more are supplied


  actions = actions.slice(0, 2);
  return _react.default.createElement(_StyledAlert.AlertActionsWrapper, _extends({
    className: getClassName(prfxCls, "-knit-alert-action-wrapper")
  }, scProps), actions.map(function (action, index) {
    return _react.default.createElement(_StyledAlert.StyledAlertAction, _extends({
      className: getClassName(prfxCls, "-knit-alert-action"),
      key: index,
      type: "secondary",
      label: action.text,
      onClick: function onClick() {
        return action.callback(alertKey);
      },
      alertType: type
    }, scProps));
  }));
};

var Alert = function Alert(props) {
  var className = props.className,
      rest = _objectWithoutProperties(props, ["className"]); // To clear autoDismiss setTimeoutInterval during unmount


  var interval;
  var scProps = {
    className: className,
    customProps: rest
  };
  var image = rest.image,
      prefixClassName = rest.prefixClassName,
      heading = rest.heading,
      multiLine = rest.multiLine,
      autoDismiss = rest.autoDismiss,
      dismissDuration = rest.dismissDuration,
      actions = rest.actions,
      onClose = rest.onClose,
      onExit = rest.onExit,
      alertKey = rest.alertKey;

  var _useState = (0, _react.useState)(true),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1]; // To get className


  var propsWithClass = function propsWithClass(suffix, className) {
    scProps.className = (prefixClassName ? "".concat(prefixClassName).concat(suffix, " ") : "") + (className ? "".concat(className, " ") : "");
    return scProps;
  };

  var isIcon = props.hasOwnProperty("icon");
  var isAction = actions && actions.length > 0; // Execute once, when Component will be mounted

  (0, _react.useEffect)(function () {
    // Show error when more than two actions are passed
    if (actions && actions.length > 2) {
      console.warn("Only two actions can be add to Alert, others will be ignored");
    } // heading only exist if multiline prop is true


    if (heading && !multiLine) {
      console.error("Please pass multiLine prop to use headings");
    } // When unmount onExit function will be called


    return function () {
      interval && clearInterval(interval);
      onExit && onExit(alertKey);
    };
  }, []); // To Auto dismiss the alert after some duration, can use transition delay check out again

  if (autoDismiss) interval = setTimeout(function () {
    return fadeAway();
  }, dismissDuration); // called by both AutoDismiss and Close Icon click

  var fadeAway = function fadeAway(event) {
    if (onClose) {
      onClose(alertKey);
    }

    setOpen(false);
  };

  return _react.default.createElement(_StyledAlert.AlertContainer, _extends({
    "data-testid": "alert-container"
  }, propsWithClass("-knit-alert", "".concat(scProps.className ? scProps.className : "").concat(open ? "" : " hide"))), (isIcon || image) && renderIcon(scProps), _react.default.createElement(_StyledAlert.AlertContentWrapper, propsWithClass("-knit-alert-content-wrapper"), heading && multiLine && _react.default.createElement(_StyledAlert.AlertHeading, propsWithClass("-knit-alert-heading"), heading), _react.default.createElement(_StyledAlert.AlertContent, propsWithClass("-knit-alert-content"), props.content), isAction && renderActions(scProps)), !autoDismiss && _react.default.createElement(_StyledAlert.CloseIcon, _extends({
    "data-testid": "alert-close",
    icon: "oClose",
    onClick: function onClick(e) {
      return fadeAway(e);
    }
  }, propsWithClass("-knit-alert-close"))));
};

Alert.defaultProps = {
  type: "neutral",
  size: "small",
  placement: "bottomLeft",
  multiLine: false,
  actions: []
};
var _default = Alert;
exports.default = _default;