"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _Icon = _interopRequireDefault(require("../Icon"));

var _components = require("./components");

var _styledComponents = require("styled-components");

var _utils = require("../../common/_utils");

var _ButtonGroup = _interopRequireDefault(require("./ButtonGroup"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var DEFAULT_COLOR_THEME = "neutral";
var insetPositions = {
  LEFT: "left",
  RIGHT: "right"
};

var ButtonWrapper = function ButtonWrapper(_ref) {
  var label = _ref.label,
      _ref$ghost = _ref.ghost,
      ghost = _ref$ghost === void 0 ? false : _ref$ghost,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? "medium" : _ref$size,
      href = _ref.href,
      _onClick = _ref.onClick,
      icon = _ref.icon,
      _ref$bare = _ref.bare,
      bare = _ref$bare === void 0 ? false : _ref$bare,
      insetLabel = _ref.insetLabel,
      _ref$insetPosition = _ref.insetPosition,
      insetPosition = _ref$insetPosition === void 0 ? "right" : _ref$insetPosition,
      _ref$colorPreset = _ref.colorPreset,
      colorPreset = _ref$colorPreset === void 0 ? DEFAULT_COLOR_THEME : _ref$colorPreset,
      customColor = _ref.customColor,
      insetCustomColor = _ref.insetCustomColor,
      customProps = _ref.customProps,
      rest = _objectWithoutProperties(_ref, ["label", "ghost", "size", "href", "onClick", "icon", "bare", "insetLabel", "insetPosition", "colorPreset", "customColor", "insetCustomColor", "customProps"]);

  var themeContext = (0, _react.useContext)(_styledComponents.ThemeContext);
  var knitui = themeContext.knitui; // Typography

  var typographySize = size === "small" ? knitui.typography[12] : knitui.typography[14];
  var iconSize = size === "small" ? "1.4rem" : "1.8rem";
  var baseFontSize = typographySize.fontSize;
  var baseLineHeight = typographySize.lineHeight;
  var insetFontSize = baseFontSize - knitui.baseIncrementUnit;
  var lowerTypographyUnit = knitui.typography["".concat(insetFontSize * 10)];
  var insetLineHeight = lowerTypographyUnit && lowerTypographyUnit.lineHeight || baseLineHeight; // Colors
  // Cannot be set as default arg since theme is not available in that context

  var DEFAULT_INSET_THEME = {
    background: knitui.chromaPalette.Neutral0,
    font: knitui.chromaPalette.Neutral80
  };
  var insetColorTheme = insetCustomColor ? (0, _utils.parseCustomColor)(knitui, insetCustomColor) : DEFAULT_INSET_THEME;
  var parsedColorTheme = customColor ? (0, _utils.parseCustomColor)(knitui, customColor) : (0, _utils.parseColorPreset)(knitui, colorPreset);
  return _react.default.createElement(_components.ButtonBase, _extends({
    customProps: {
      label: label,
      icon: icon,
      ghost: ghost,
      size: size,
      bare: bare,
      colorTheme: parsedColorTheme,
      fontSize: baseFontSize,
      lineHeight: baseLineHeight
    },
    onClick: function onClick(e) {
      return _onClick && _onClick(e) || href && window.location.assign(href);
    }
  }, rest), insetLabel && insetPosition === insetPositions.LEFT && _react.default.createElement(_components.ButtonInset, {
    customProps: {
      insetPosition: insetPosition,
      size: size,
      backgroundColor: insetColorTheme.background,
      fontColor: insetColorTheme.font,
      fontSize: "".concat(insetFontSize, "rem"),
      lineHeight: "".concat(insetLineHeight, "rem")
    }
  }, _react.default.createElement("span", null, insetLabel)), _react.default.createElement(_components.ButtonContent, {
    customProps: {
      label: label,
      icon: icon,
      ghost: ghost,
      size: size,
      bare: bare,
      colorTheme: parsedColorTheme,
      fontSize: baseFontSize,
      lineHeight: baseLineHeight
    }
  }, icon ? _react.default.createElement(_Icon.default, {
    type: icon,
    size: iconSize
  }) : null, label), insetLabel && insetPosition === insetPositions.RIGHT && _react.default.createElement(_components.ButtonInset, {
    customProps: {
      insetPosition: insetPosition,
      size: size,
      backgroundColor: insetColorTheme.background,
      fontColor: insetColorTheme.font,
      fontSize: "".concat(insetFontSize, "rem"),
      lineHeight: "".concat(insetLineHeight, "rem")
    }
  }, _react.default.createElement("span", null, insetLabel)));
};

ButtonWrapper.Group = _ButtonGroup.default;
var _default = ButtonWrapper;
exports.default = _default;