"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _utils = require("../../../common/_utils");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

// Paddings
var ICON_PADDINGS = {
  small: 0.3,
  medium: 0.5,
  large: 0.7
};
var VERTICAL_PADDINGS = {
  small: 0.2,
  medium: 0.4,
  large: 0.7 // Colors

};

var getHighlighColor = function getHighlighColor(props) {
  return props.theme.knitui.chromaPalette.Azure80;
};

var getBaseBackgroundColor = function getBaseBackgroundColor(props) {
  var _props$customProps = props.customProps,
      ghost = _props$customProps.ghost,
      colorTheme = _props$customProps.colorTheme;
  return ghost ? colorTheme.font : colorTheme.background;
};

var getBaseFontColor = function getBaseFontColor(props) {
  var _props$customProps2 = props.customProps,
      ghost = _props$customProps2.ghost,
      colorTheme = _props$customProps2.colorTheme;
  return ghost ? colorTheme.background : colorTheme.font;
};

var getFontColor = function getFontColor(state, props) {
  var _props$customProps3 = props.customProps,
      bare = _props$customProps3.bare,
      ghost = _props$customProps3.ghost;
  var baseFontColor = getBaseFontColor(props);

  switch (state) {
    case "default":
      if (bare) {
        return getBaseBackgroundColor(props);
      }

      return baseFontColor;

    case "hover":
    case "active":
    case "focus":
      if (bare) {
        return (0, _utils.getHoverBackgroundColor)(getBaseBackgroundColor(props));
      }

      if (ghost) {
        return (0, _utils.getHoverFontColor)(getBaseFontColor(props));
      }

      return baseFontColor;

    default:
      return baseFontColor;
  }
};

var getBackgroundColor = function getBackgroundColor(state, props) {
  var _props$customProps4 = props.customProps,
      bare = _props$customProps4.bare,
      ghost = _props$customProps4.ghost,
      knitui = props.theme.knitui;

  if (bare) {
    return knitui.shades.transparent;
  }

  if (ghost) {
    return knitui.chromaPalette.Neutral0; // white
  }

  return state === "default" ? getBaseBackgroundColor(props) : (0, _utils.getHoverBackgroundColor)(getBaseBackgroundColor(props));
};

var getBorder = function getBorder(state, props) {
  var ghost = props.customProps.ghost,
      knitui = props.theme.knitui;
  var borderColor;

  switch (state) {
    case "active":
    case "focus":
      borderColor = getHighlighColor(props);
      break;

    case "hover":
      borderColor = ghost ? (0, _utils.getHoverFontColor)(getBaseFontColor(props)) : knitui.shades.transparent;
      break;

    default:
      borderColor = ghost ? getBaseFontColor(props) : knitui.shades.transparent;
      break;
  }

  return "1px solid ".concat(borderColor);
};

var getIconMargin = function getIconMargin(props) {
  var _props$customProps5 = props.customProps,
      icon = _props$customProps5.icon,
      label = _props$customProps5.label,
      size = _props$customProps5.size;
  return icon && label ? size === "small" ? "0.2rem" : "0.4rem" : "0rem";
};

var getBoxShadow = function getBoxShadow(props) {
  var knitui = props.theme.knitui;
  return "0px 0px 2px ".concat(knitui.shades.blue50);
};

var getHorizontalPadding = function getHorizontalPadding(props) {
  var size = props.customProps.size;
  var paddings = {
    small: 0.7,
    medium: 1,
    large: 1
  };
  return paddings[size];
};

var getRightPadding = function getRightPadding(props) {
  var _props$customProps6 = props.customProps,
      icon = _props$customProps6.icon,
      label = _props$customProps6.label,
      size = _props$customProps6.size;

  if (icon && !label) {
    return ICON_PADDINGS[size];
  }

  return getHorizontalPadding(props);
};

var getLeftPadding = function getLeftPadding(props) {
  var _props$customProps7 = props.customProps,
      icon = _props$customProps7.icon,
      size = _props$customProps7.size;

  if (icon) {
    return ICON_PADDINGS[size];
  }

  return getHorizontalPadding(props);
};

var getVerticalPadding = function getVerticalPadding(props) {
  var _props$customProps8 = props.customProps,
      icon = _props$customProps8.icon,
      label = _props$customProps8.label,
      size = _props$customProps8.size;
  var iconOnly = icon && !label;
  return iconOnly ? ICON_PADDINGS[size] : VERTICAL_PADDINGS[size];
};

var StyledButton =
/*#__PURE__*/
_styledComponents.default.button.withConfig({
  displayName: "ButtonBase__StyledButton",
  componentId: "sc-1f4e27b-0"
})(["display:flex;align-items:center;width:", ";font-size:", ";line-height:", ";color:", ";background-color:", ";border-radius:0.4rem;border-style:none;box-sizing:border-box;border:", ";padding-left:", ";padding-right:", ";padding-top:", ";padding-bottom:", ";span{margin-right:", ";svg path{fill:", ";}}", ":disabled{opacity:0.5;cursor:not-allowed;}"], function (_ref) {
  var customProps = _ref.customProps;
  return customProps.size === "fluid" ? "100%" : "auto";
}, function (_ref2) {
  var fontSize = _ref2.customProps.fontSize;
  return "".concat(fontSize, "rem");
}, function (_ref3) {
  var lineHeight = _ref3.customProps.lineHeight;
  return "".concat(lineHeight, "rem");
}, function (props) {
  return getFontColor("default", props);
}, function (props) {
  return getBackgroundColor("default", props);
}, function (props) {
  return getBorder("default", props);
}, function (props) {
  return "".concat(getLeftPadding(props), "rem");
}, function (props) {
  return "".concat(getRightPadding(props), "rem");
}, function (props) {
  return "".concat(getVerticalPadding(props), "rem");
}, function (props) {
  return "".concat(getVerticalPadding(props), "rem");
}, function (props) {
  return getIconMargin(props);
}, function (props) {
  return getFontColor("default", props);
}, function (_ref4) {
  var disabled = _ref4.disabled;
  return !disabled && (0, _styledComponents.css)([":hover,:active,:focus{color:", ";background-color:", ";svg path{fill:", ";}cursor:pointer;}:active,:focus{border:", " !important;box-shadow:", ";outline:none;}:hover{border:", ";}"], function (props) {
    return getFontColor("hover", props);
  }, function (props) {
    return getBackgroundColor("hover", props);
  }, function (props) {
    return getFontColor("hover", props);
  }, function (props) {
    return getBorder("active", props);
  }, function (props) {
    return getBoxShadow(props);
  }, function (props) {
    return getBorder("hover", props);
  });
});

var _default = StyledButton;
exports.default = _default;