"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _downshift = require("downshift");

var _palette = require("../../common/styles/palette");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var menuStyles = {
  backgroundColor: "white",
  fontWeight: "normal",
  position: "absolute"
};
var textContentStyle = {
  position: "absolute",
  top: 0,
  left: 0,
  visibility: "hidden",
  height: 0,
  overflow: "scroll",
  whiteSpace: "pre"
};

var DropdownCombobox = function DropdownCombobox(props) {
  var inputRef = props.inputRef,
      inputPlaceholder = props.inputPlaceholder,
      onKeyDown = props.onKeyDown,
      handleValueChange = props.handleValueChange,
      options = props.options,
      validationFn = props.validationFn,
      inputValue = props.inputValue,
      expressionInputClass = props.expressionInputClass;

  var _useState = (0, _react.useState)(options),
      _useState2 = _slicedToArray(_useState, 2),
      inputItems = _useState2[0],
      setInputItems = _useState2[1];

  var _useState3 = (0, _react.useState)(true),
      _useState4 = _slicedToArray(_useState3, 2),
      valid = _useState4[0],
      setValid = _useState4[1];

  var _useState5 = (0, _react.useState)("string"),
      _useState6 = _slicedToArray(_useState5, 2),
      valueType = _useState6[0],
      setValueType = _useState6[1];

  var matchesAnInput = options.some(function (item) {
    return item.label === inputValue;
  });
  var textRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    setInputItems(options.filter(function (item) {
      return item.key.toLowerCase().startsWith(inputValue.toLowerCase());
    }));

    if (validationFn) {
      validationFn(inputValue) || matchesAnInput ? setValid(true) : setValid(false);
    }
  }, [inputValue]);

  var handleValueTypeChange = function handleValueTypeChange(val) {
    // check if the input value is present in any of the option
    var isPresentInOptions = options.find(function (option) {
      return option.label === val;
    });

    if (isPresentInOptions) {
      setValueType(isPresentInOptions.type);
    } else {
      setValueType("string"); // can also use typeof formattedInputValue but it will result in string anyways
    }
  };

  var stateReducer = function stateReducer(state, actionAndChanges) {
    var stateChangeTypes = _downshift.useCombobox.stateChangeTypes;

    switch (actionAndChanges.type) {
      case stateChangeTypes.ItemClick:
      case stateChangeTypes.InputKeyDownEnter:
        // case useCombobox.stateChangeTypes.InputBlur:
        handleValueChange({
          target: {
            value: state.highlightedIndex > -1 ? actionAndChanges.changes.selectedItem.label : actionAndChanges.changes.inputValue || ""
          }
        });

        if (state.highlightedIndex > -1) {
          // handleValueTypeChange(actionAndChanges.changes.selectedItem.label)
          setValueType(actionAndChanges.changes.selectedItem.type);
        }

        return _objectSpread({}, actionAndChanges.changes, state.highlightedIndex > -1 && {
          inputValue: actionAndChanges.changes.selectedItem.key
        });

      default:
        return actionAndChanges.changes;
      // otherwise business as usual.
    }
  };

  var _useCombobox = (0, _downshift.useCombobox)({
    items: inputItems,
    defaultIsOpen: true,
    initialIsOpen: true,
    initialHighlightedIndex: 0,
    stateReducer: stateReducer
  }),
      isOpen = _useCombobox.isOpen,
      openMenu = _useCombobox.openMenu,
      getMenuProps = _useCombobox.getMenuProps,
      getInputProps = _useCombobox.getInputProps,
      getComboboxProps = _useCombobox.getComboboxProps,
      highlightedIndex = _useCombobox.highlightedIndex,
      getItemProps = _useCombobox.getItemProps;

  var updateValueAndType = function updateValueAndType(e) {
    var val = e.target.value;
    handleValueChange(e);
    handleValueTypeChange(val);
  };

  var getInputWidth = function getInputWidth() {
    if (textRef.current) {
      return textRef.current.scrollWidth + 8;
    }

    return "10rem";
  };

  var showMenu = isOpen && !matchesAnInput && inputItems.length > 0;
  return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("div", _extends({
    "data-type": "expression-input-root"
  }, getComboboxProps(), {
    className: expressionInputClass
  }), _react.default.createElement("input", _extends({}, getInputProps({
    onChange: updateValueAndType,
    onKeyDown: onKeyDown,
    value: inputValue,
    ref: inputRef,
    placeholder: inputPlaceholder,
    onFocus: function onFocus() {
      return openMenu();
    }
  }), {
    style: {
      width: getInputWidth()
    },
    "data-valid": valid,
    "data-value-type": valueType
  })), _react.default.createElement("div", {
    ref: textRef,
    style: textContentStyle
  }, inputValue || inputPlaceholder), showMenu && _react.default.createElement("ul", _extends({
    "data-type": "expression-list"
  }, getMenuProps(), {
    style: menuStyles
  }), inputItems.map(function (item, index) {
    return _react.default.createElement("li", _extends({
      "data-type": "expression-list-item",
      "data-item-type": item.type,
      style: highlightedIndex === index ? {
        backgroundColor: _palette.Neutral10.hex
      } : {},
      key: "".concat(item.key).concat(index)
    }, getItemProps({
      item: item,
      index: index
    })), _react.default.createElement("span", null, item.label), _react.default.createElement("span", null, item.keyLabel || ""));
  }))));
};

var _default = DropdownCombobox;
exports.default = _default;