"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _Expression = _interopRequireDefault(require("./Expression"));

var _DownSelect = _interopRequireDefault(require("./DownSelect"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var Drop = function Drop(props) {
  var placeholder = props.placeholder,
      EditorData = props.EditorData,
      node = props.node,
      _props$initialFocus = props.initialFocus,
      initialFocus = _props$initialFocus === void 0 ? false : _props$initialFocus,
      options = props.options,
      validationFn = props.validationFn,
      onChangeFn = props.onChangeFn,
      expressionRootClass = props.expressionRootClass,
      expressionInputClass = props.expressionInputClass;

  var _useState = (0, _react.useState)(""),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = (0, _react.useState)(false),
      _useState4 = _slicedToArray(_useState3, 2),
      exp = _useState4[0],
      setExp = _useState4[1];

  var dropRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    if (dropRef.current && initialFocus) {
      dropRef.current.focus();
    }
  }, [dropRef.current]);
  var fnKeys = options.filter(function (fn) {
    return fn.type === "function";
  }).map(function (fn) {
    return fn.key;
  });

  var getValueType = function getValueType(value) {
    if (fnKeys.includes(value.toLowerCase())) return "fn";
    var listOption = options.find(function (option) {
      return option.label === value;
    });
    return listOption ? listOption.type : "string";
  };

  var getValueData = function getValueData(type, value) {
    if (type === "fn") {
      return options.find(function (f) {
        return f.key === value.toLowerCase();
      });
    }

    return value;
  };

  var handleValueChange = function handleValueChange(e) {
    var val = e.target.value;
    var valueType = getValueType(val);
    var valueData = getValueData(valueType, val);
    setValue(val);
    node.setValue({
      data: valueData,
      type: valueType
    }); // In case the input is a function, scaffold it's params

    if (valueType === "fn") setExp(true);
    if (onChangeFn) onChangeFn(EditorData);
  };

  var getNextNode = function getNextNode() {
    var currElement;

    if (dropRef.current) {
      currElement = dropRef.current.parentElement;
    } // if the present element has a next sibling, directly switch to next


    if (currElement.nextElementSibling) currElement = currElement.nextElementSibling; // this is when you want to skip the top levels and only switch in text fields
    else {
        while (!currElement.nextElementSibling) {
          currElement = currElement.parentElement;
          if (currElement.dataset.type === "knit-ui_extractor-root") return;
        }

        currElement = currElement.nextElementSibling;
      }
    if (currElement.dataset.type !== "expression-root") currElement = currElement.firstElementChild;
    return currElement;
  };

  var getPrevNode = function getPrevNode() {
    var currElement;

    if (dropRef.current) {
      currElement = dropRef.current.parentElement;
    } // if the present element has a next sibling, directly switch to next


    if (currElement.previousElementSibling) currElement = currElement.previousElementSibling;else {
      if (!currElement.previousElementSibling) currElement = currElement.parentElement;
    } // some transitions as per the element we arrive on

    while (currElement.dataset.type === "expression-root" && !initialFocus) {
      currElement = currElement.lastElementChild;
    }

    if (currElement.dataset.type === "expression-input-root") {
      currElement = currElement.firstElementChild;
    }

    return currElement;
  };

  var handleDir = function handleDir(e) {
    e.stopPropagation();
    var inputNode = dropRef.current;

    switch (e.keyCode) {
      case 39:
        // only  at last caret position
        if (inputNode.selectionStart !== inputNode.value.length) return;
        e.preventDefault();
        var nextNode = getNextNode();
        if (nextNode) nextNode.focus();
        break;

      case 37:
        // only when at caret position is 0
        if (inputNode.selectionStart !== 0) return;
        e.preventDefault();
        var prevNode = getPrevNode();
        if (prevNode) prevNode.focus();
        break;

      default:
        break;
    }
  };

  if (!exp) {
    return _react.default.createElement(_DownSelect.default, {
      inputRef: dropRef,
      inputPlaceholder: placeholder,
      options: options,
      onKeyDown: function onKeyDown(e) {
        return handleDir(e);
      },
      inputValue: value,
      validationFn: validationFn,
      expressionInputClass: expressionInputClass,
      handleValueChange: handleValueChange
    });
  }

  return _react.default.createElement(_Expression.default, {
    EditorData: EditorData,
    options: options,
    setExp: setExp,
    setValue: setValue,
    node: node,
    onChangeFn: onChangeFn,
    validationFn: validationFn,
    expressionRootClass: expressionRootClass,
    expressionInputClass: expressionInputClass,
    fname: value
  });
};

var _default = Drop;
exports.default = _default;