"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _utils = require("./utils");

var _RenderInput = _interopRequireDefault(require("./RenderInput"));

var _InputAddons = _interopRequireDefault(require("./InputAddons"));

var _styledComponents = require("./styledComponents");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var InputRef = _react.default.forwardRef(function (props, ref) {
  var _useState = (0, _react.useState)(props.value || ""),
      _useState2 = _slicedToArray(_useState, 2),
      currentValue = _useState2[0],
      setCurrentValue = _useState2[1];

  var _useState3 = (0, _react.useState)(props.type === "password"),
      _useState4 = _slicedToArray(_useState3, 2),
      isPasswordField = _useState4[0],
      setIsPasswordField = _useState4[1];

  var _useState5 = (0, _react.useState)(false),
      _useState6 = _slicedToArray(_useState5, 2),
      isOverflow = _useState6[0],
      setIsOverflow = _useState6[1];

  (0, _react.useEffect)(function () {
    // To update the current input value
    setCurrentValue(props.value);
  }, [props.value]);
  var currentRef = (0, _react.useRef)(null);
  var customProps = {
    inputSize: props.inputSize,
    state: props.state
  };

  var handleChange = function handleChange(e) {
    // Handle onChange if provided and update the input value
    if (props.onChange) {
      props.onChange(e);
    }

    setCurrentValue(e.target.value);
  };

  var handleFocus = function handleFocus(e) {
    if (props.onFocus) {
      props.onFocus(e);
    }

    setIsOverflow(false);
  };

  var handleBlur = function handleBlur(e) {
    if (props.onBlur) {
      props.onBlur(e);
    }

    if (currentRef.current) {
      var input = currentRef.current.children[0];

      if (input.scrollWidth > input.clientWidth && !isOverflow) {
        setIsOverflow(true);
      } else if (input.scrollWidth <= input.clientWidth && isOverflow) {
        setIsOverflow(false);
      }
    }
  };

  var clearInput = function clearInput(e) {
    e.preventDefault();
    setCurrentValue("");
    var input = currentRef.current.children[0];

    if (!input) {
      return;
    } // Updating state programatically does not fire onChange event.
    // The following workaround is implemented to fire onChange.
    // Reference: https://github.com/facebook/react/issues/10135#issuecomment-401496776


    var _ref = Object.getOwnPropertyDescriptor(input, "value") || {},
        valueSetter = _ref.set;

    var prototype = Object.getPrototypeOf(input);

    var _ref2 = Object.getOwnPropertyDescriptor(prototype, "value") || {},
        prototypeValueSetter = _ref2.set;

    if (prototypeValueSetter && valueSetter !== prototypeValueSetter) {
      prototypeValueSetter.call(input, "");
    } else if (valueSetter) {
      valueSetter.call(input, "");
    }

    var event = new Event("input", {
      bubbles: true
    });
    input.dispatchEvent(event);
    input.focus();
  };

  var togglePasswordField = function togglePasswordField() {
    setIsPasswordField(function (prevState) {
      return !prevState;
    });
  };

  var getCurrentInputType = function getCurrentInputType() {
    // Get the input type. Useful while toggling password field.
    if (props.type === "number") {
      return "number";
    } else if (props.type === "textarea") {
      return "textarea";
    } else if (isPasswordField) {
      return "password";
    }

    return "default";
  }; // Implemented to save the effort of adding `getIconSize` on every Icon component


  var Icon = function Icon(iconProps) {
    return _react.default.createElement(_styledComponents.AddonIcon, _extends({
      size: (0, _utils.getIconSize)(props.inputSize)
    }, iconProps));
  };

  var InputElem = _react.default.createElement(_styledComponents.InputWrapper, {
    inputSize: props.inputSize,
    type: props.type,
    state: props.state,
    addonAfter: props.addonAfter,
    ref: currentRef,
    customProps: customProps,
    isOverflow: isOverflow
  }, _react.default.createElement(_RenderInput.default, _extends({}, props, {
    ref: ref,
    value: currentValue,
    onChange: handleChange,
    type: getCurrentInputType(),
    isOverflow: isOverflow,
    onBlur: handleBlur,
    onFocus: handleFocus
  })));

  var addonAfter = props.addonAfter;

  if (props.type === "search") {
    if (currentValue && currentValue.toString().length > 0) {
      addonAfter = _react.default.createElement(_styledComponents.IconBackground, {
        bgSize: (0, _utils.getIconSize)(props.inputSize)
      }, _react.default.createElement(Icon, {
        type: "oClose",
        fill: "#000000",
        onMouseDown: clearInput,
        pointer: true
      }));
    } else {
      addonAfter = _react.default.createElement(Icon, {
        type: "oSearch",
        fill: "#a6a6a6"
      });
    }
  } else if (props.type === "password") {
    if (isPasswordField) {
      addonAfter = _react.default.createElement(Icon, {
        type: "oVisibility",
        fill: "#000000",
        onClick: togglePasswordField,
        pointer: true
      });
    } else {
      addonAfter = _react.default.createElement(Icon, {
        type: "oVisibilityOff",
        fill: "#000000",
        onClick: togglePasswordField,
        pointer: true
      });
    }
  } else if (props.state === "success") {
    addonAfter = _react.default.createElement(Icon, {
      type: "oCheckCircleOutline",
      fill: "#036600"
    });
  } else if (props.state === "warning") {
    addonAfter = _react.default.createElement(Icon, {
      type: "oWarning",
      fill: "#FFC700"
    });
  } else if (props.state === "error") {
    addonAfter = _react.default.createElement(Icon, {
      type: "oErrorOutline",
      fill: "#990000"
    });
  }

  return (0, _InputAddons.default)(InputElem, _objectSpread({}, props, {
    addonAfter: addonAfter
  }));
});

var _default = InputRef;
exports.default = _default;