"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAddonPadding = exports.getIconSize = exports.getInputType = exports.getSelectionBackground = exports.getBoxShadow = exports.getColor = exports.getBorderRadius = exports.getBackgroundColor = exports.getLineHeight = exports.getFontSize = exports.getHeight = exports.getInputBorder = exports.getPadding = void 0;

var _utils = require("../../common/_utils");

var getPadding = function getPadding(props) {
  var inputSize = props.customProps.inputSize;
  var HORIZONTAL_PADDING = "1rem";

  switch (inputSize) {
    case "small":
      return "0.1rem  ".concat(HORIZONTAL_PADDING);

    case "large":
      return "0.7rem  ".concat(HORIZONTAL_PADDING);

    default:
      return "0.4rem  ".concat(HORIZONTAL_PADDING);
  }
};

exports.getPadding = getPadding;
var inputSizeToTypographySize = {
  small: 12,
  default: 14,
  large: 14
};

var getInputBorderColor = function getInputBorderColor(props, state) {
  var knitui = props.theme.knitui,
      inputState = props.customProps.state;

  if (inputState === "success") {
    return knitui.inputSuccessBorder;
  }

  if (inputState === "warning") {
    return knitui.inputWarningBorder;
  }

  if (inputState === "error") {
    return knitui.inputErrorBorder;
  }

  if (state === "focus" || state === "active") {
    return knitui.inputFocusBorderColor;
  }

  if (state === "hover") {
    return knitui.inputHoverBorderColor;
  }

  return knitui.inputBorderColor;
};

var getInputBorder = function getInputBorder(props, state) {
  return "1px solid ".concat(getInputBorderColor(props, state));
};

exports.getInputBorder = getInputBorder;

var getHeight = function getHeight(props) {
  var inputSize = props.customProps.inputSize;

  switch (inputSize) {
    case "small":
      return "2.2rem";

    case "large":
      return "3.6rem";

    default:
      return "3rem";
  }
};

exports.getHeight = getHeight;

var getFontSize = function getFontSize(props) {
  var inputSize = props.customProps.inputSize;
  var typographySize = inputSizeToTypographySize[inputSize];
  return (0, _utils.getThemeFontSize)(props, typographySize);
};

exports.getFontSize = getFontSize;

var getLineHeight = function getLineHeight(props) {
  var inputSize = props.customProps.inputSize;
  var typographySize = inputSizeToTypographySize[inputSize];
  return (0, _utils.getThemeLineHeight)(props, typographySize);
};

exports.getLineHeight = getLineHeight;

var getBackgroundColor = function getBackgroundColor(props, state) {
  var knitui = props.theme.knitui;

  if (state && state === "focus") {
    return knitui.inputBgFocus;
  }

  return knitui.inputBgDefault;
};

exports.getBackgroundColor = getBackgroundColor;

var getBorderRadius = function getBorderRadius(props) {
  var knitui = props.theme.knitui;
  return knitui.inputBorderRadius;
};

exports.getBorderRadius = getBorderRadius;

var getColor = function getColor(props) {
  var state = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : "default";
  var knitui = props.theme.knitui;

  if (state === "placeholder") {
    return knitui.inputPlaceholderColor;
  }

  if (state === "label") {
    return knitui.inputLabelColor;
  }

  if (state === "notification") {
    return knitui.inputNotificationColor;
  }

  return knitui.inputColor;
};

exports.getColor = getColor;

var getBoxShadow = function getBoxShadow(props, state) {
  var knitui = props.theme.knitui;

  if (state && (state === "active" || state === "focus")) {
    return knitui.inputFocusBoxShadow;
  }

  return "";
};

exports.getBoxShadow = getBoxShadow;

var getSelectionBackground = function getSelectionBackground(props) {
  var knitui = props.theme.knitui;
  return knitui.inputSelectionBg;
};

exports.getSelectionBackground = getSelectionBackground;

var getInputType = function getInputType(type) {
  if (type === "password") {
    return "password";
  } else if (type === "number") {
    return "number";
  }

  return "text";
};

exports.getInputType = getInputType;

var getIconSize = function getIconSize(inputSize) {
  // Get addonIcon size as per input size
  if (inputSize === "small") {
    return "14px";
  } else if (inputSize === "large") {
    return "18px";
  }

  return "16px";
};

exports.getIconSize = getIconSize;

var getAddonPadding = function getAddonPadding(iconSize) {
  // Returns the padding for addon as per icon size (in `rem`)
  return 1 + parseInt(iconSize) / 10 + 1;
};

exports.getAddonPadding = getAddonPadding;