"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _styledComponents = _interopRequireWildcard(require("styled-components"));

var _lodash = _interopRequireDefault(require("lodash"));

var _Icon = _interopRequireDefault(require("../Icon"));

var _InlineLabel = _interopRequireDefault(require("./InlineLabel"));

var _commonUtils = require("./commonUtils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var DEFAULT_COLOR_THEME = "neutral";
var INSET_BACKGROUND_COLOR = "#F7F7F7";
var typographySize = {
  small: 12,
  medium: 14,
  large: 14
};

var getFontSize = function getFontSize(props) {
  var typography = props.theme.knitui.typography,
      size = props.customProps.size;
  return typography[typographySize[size]].fontSize;
};

var geLineHeight = function geLineHeight(props) {
  var typography = props.theme.knitui.typography,
      size = props.customProps.size;
  return typography[typographySize[size]].lineHeight;
};

var getDarkenedBorderColor = function getDarkenedBorderColor(props) {
  return (0, _commonUtils.getBackgroundColor)(props).set("hsl.l", "-0.2");
};

var showLeftIcon = function showLeftIcon(props) {
  var icons = props.customProps.icons;
  return icons && icons.left;
};

var showRightIcon = function showRightIcon(props) {
  var icons = props.customProps.icons;
  return icons && icons.right;
};

var verticalPadding = {
  small: 0,
  medium: 0.1,
  large: 0.3
};

var getIconPadding = function getIconPadding(size) {
  return size === "small" ? 0.2 : 0.4;
};

var getPadding = function getPadding(props) {
  var _props$customProps = props.customProps,
      size = _props$customProps.size,
      expanded = _props$customProps.expanded,
      outlined = _props$customProps.outlined,
      defaultBorderWidth = props.theme.knitui.defaultBorderWidth;
  var defaultHorizontalPadding = expanded ? 0.9 : 0.6;
  var left = defaultHorizontalPadding;
  var right = defaultHorizontalPadding;
  var vertical = verticalPadding[size];

  if (showLeftIcon(props)) {
    left = getIconPadding(size);
  }

  if (showRightIcon(props)) {
    right = getIconPadding(size);
  }

  return "".concat(vertical, "rem ").concat(right, "rem ").concat(vertical, "rem ").concat(left, "rem");
};

var getTextMargin = function getTextMargin(props) {
  var size = props.customProps.size;
  return size === "small" ? "0.2rem" : "0.4rem";
};

var getTextLeftMargin = function getTextLeftMargin(props) {
  return showLeftIcon(props) ? getTextMargin(props) : "0rem";
};

var getTextRightMargin = function getTextRightMargin(props) {
  return showRightIcon(props) ? getTextMargin(props) : "0rem";
};

var getBorder = function getBorder(props) {
  var outlined = props.customProps.outlined,
      defaultBorderWidth = props.theme.knitui.defaultBorderWidth;
  var borderColor = outlined ? getDarkenedBorderColor(props) : "transparent";
  return "".concat(defaultBorderWidth, "rem solid ").concat(borderColor);
};

var getBorderRadius = function getBorderRadius(props) {
  var rounded = props.customProps.rounded;
  return rounded ? "999px" : "0.2rem";
};

var getBoxShadow = function getBoxShadow(props) {
  var shades = props.theme.knitui.shades,
      focus = props.customProps.focus;
  return focus ? "0rem 0rem 0.2rem ".concat(shades.blue50) : "none";
};

var getInsetStyles = function getInsetStyles(props) {
  var insetColor = props.insetColor;
  return insetColor ? (0, _styledComponents.css)(["&::before{content:\"\";position:absolute;top:0;bottom:0;left:0;width:0.3rem;background:", ";border-radius:0.2rem 0 0 0.2rem;}"], insetColor) : "";
};

var LabelContainer =
/*#__PURE__*/
_styledComponents.default.div.withConfig({
  displayName: "Label__LabelContainer",
  componentId: "sc-1n9e7xv-0"
})(["display:inline-flex;position:relative;"]);

var StyledDiv =
/*#__PURE__*/
_styledComponents.default.div.withConfig({
  displayName: "Label__StyledDiv",
  componentId: "sc-1n9e7xv-1"
})(["display:inline-flex;align-items:center;padding:", ";background-color:", ";color:", ";font-size:", ";line-height:", ";border-radius:", ";border:", ";box-sizing:border-box;box-shadow:", ";overflow:hidden;", ""], function (props) {
  return getPadding(props);
}, function (props) {
  return (0, _commonUtils.getBackgroundColor)(props);
}, function (props) {
  return (0, _commonUtils.getFontColor)(props);
}, function (props) {
  return "".concat(getFontSize(props), "rem");
}, function (props) {
  return "".concat(geLineHeight(props), "rem");
}, function (props) {
  return getBorderRadius(props);
}, function (props) {
  return getBorder(props);
}, function (props) {
  return getBoxShadow(props);
}, function (props) {
  return getInsetStyles(props);
});

var StyledTextSpan =
/*#__PURE__*/
_styledComponents.default.span.withConfig({
  displayName: "Label__StyledTextSpan",
  componentId: "sc-1n9e7xv-2"
})(["margin:0rem ", " 0rem ", ";"], function (props) {
  return getTextRightMargin(props);
}, function (props) {
  return getTextLeftMargin(props);
});

var Label = function Label(props) {
  var labelPropKeys = ["size", "rounded", "outlined", "icons", "focus", "insetColor", "text", "expanded", "colorPreset", "customColor", "customFontColor"];

  var labelProps = _lodash.default.pick(props, labelPropKeys);

  var otherProps = _lodash.default.omit(props, labelPropKeys);

  var text = labelProps.text,
      insetColor = labelProps.insetColor,
      icons = labelProps.icons;
  /**
   * Styled Component theme should be needed here, because getFontColor take theme
   * as argument
   */

  var theme = (0, _react.useContext)(_styledComponents.ThemeContext);
  /**
   * If an insetColor is specified, the background color should be set to a default unless
   * explicitly provided through customColor
   */

  if (insetColor) {
    labelProps.customColor = labelProps.customColor || INSET_BACKGROUND_COLOR;
  }

  var scProps = {
    theme: theme,
    customProps: labelProps
  };

  var renderLeftIcon = function renderLeftIcon() {
    if (!showLeftIcon(scProps)) {
      return null;
    }

    if (_lodash.default.isString(icons.left)) {
      return _react.default.createElement(_Icon.default, {
        fill: (0, _commonUtils.getFontColor)(scProps),
        type: icons.left
      });
    }

    return icons.left;
  };

  var renderRightIcon = function renderRightIcon() {
    if (!showRightIcon(scProps)) {
      return null;
    }

    if (_lodash.default.isString(icons.right)) {
      return _react.default.createElement(_Icon.default, {
        fill: (0, _commonUtils.getFontColor)(scProps),
        type: icons.right
      });
    }

    return icons.right;
  }; //For styled components, we separate the props that are to be loaded on the DOM


  return _react.default.createElement(LabelContainer, null, _react.default.createElement(StyledDiv, _extends({}, scProps, otherProps, {
    insetColor: insetColor
  }), renderLeftIcon(), _react.default.createElement(StyledTextSpan, scProps, text), renderRightIcon()));
};

Label.defaultProps = {
  expanded: false,
  size: "medium",
  rounded: false,
  outlined: false,
  colorPreset: DEFAULT_COLOR_THEME,
  focus: false
};
Label.Inline = _InlineLabel.default;
var _default = Label;
exports.default = _default;